@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2008, 2015 Angelo Zerr and others.
+ * Copyright (c) 2008, 2019 Angelo Zerr and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -216,9 +216,7 @@ public abstract class AbstractCSSEngine implements CSSEngine {
 					}
 				}
 			}
-			InputStream stream = null;
-			try {
-				stream = url.openStream();
+			try (InputStream stream = url.openStream()) {
 				InputSource tempStream = new InputSource();
 				tempStream.setURI(url.toString());
 				tempStream.setByteStream(stream);
@@ -232,10 +230,6 @@ public abstract class AbstractCSSEngine implements CSSEngine {
 				for (int j = 0; j < tempRules.getLength(); j++) {
 					masterList.add(tempRules.item(j));
 				}
-			} finally {
-				if (stream != null) {
-					stream.close();
-				}
 			}
 		}
 
@@ -1068,6 +1062,9 @@ public abstract class AbstractCSSEngine implements CSSEngine {
 
 	@Override
 	public Object convert(CSSValue value, Object toType, Object context) throws Exception {
+		if ("unset".equals(value.getCssText())) {
+			return null;
+		}
 		Object key = keyFactory.createKey(value);
 		Object newValue = getResource(toType, key);
 
