@@ -85,6 +85,8 @@ public class ThemeEngine implements IThemeEngine {
 
 	public static final String THEME_PLUGIN_ID = "org.eclipse.e4.ui.css.swt.theme";
 
+	public static final String E4_DARK_THEME_ID = "org.eclipse.e4.ui.css.theme.e4_dark";
+
 	public ThemeEngine(Display display) {
 		this.display = display;
 
@@ -108,34 +110,6 @@ public class ThemeEngine implements IThemeEngine {
 			modDir.mkdirs();
 		}
 
-		//Check for old css files
-		File oldModDir= new File(
-				System.getProperty("user.home") + File.separator + ".e4css" + File.separator); //$NON-NLS-1$ //$NON-NLS-2$
-		if (oldModDir.exists()) {
-			File done = new File(oldModDir, ".processed");
-			if (!done.exists()) {
-				// copy over files into config area
-				try {
-					done.createNewFile();
-					File[] oldModifiedFiles = oldModDir.listFiles();
-					if (oldModifiedFiles == null) {
-						throw new IOException(
-								"Content from directory '" + oldModDir.getAbsolutePath() + "' can not be listed."); //$NON-NLS-1$ //$NON-NLS-2$
-					}
-					for (File oldModifiedFile : oldModifiedFiles) {
-						if (oldModifiedFile.getName().contains(".css")) {
-							copyFile(oldModifiedFile.getPath(), path
-									+ File.separator
-									+ oldModifiedFile.getName());
-						}
-					}
-				} catch (IOException e1) {
-					/* ignore */
-				}
-			}
-		}
-
-
 		File[] modifiedFiles = modDir.listFiles();
 		String currentOS = Platform.getOS();
 		String currentWS = Platform.getWS();
@@ -143,21 +117,27 @@ public class ThemeEngine implements IThemeEngine {
 			for (IConfigurationElement ce : e.getConfigurationElements()) {
 				if (ce.getName().equals("theme")) {
 					try {
+						String id = ce.getAttribute("id");
+						String os = ce.getAttribute("os");
 						String version = ce.getAttribute("os_version");
+
 						if (version == null) {
 							version ="";
+						} else {
+							// For e4 dark theme on Mac, register the theme with matching OS version only
+							if (E4_DARK_THEME_ID.equals(id) && Platform.OS_MACOSX.equals(currentOS) && os != null
+									&& os.equals(currentOS)) {
+								if (!isOsVersionMatch(version)) {
+									continue;
+								} else {
+									version = "";
+								}
+							}
 						}
-						String originalCSSFile;
-						String basestylesheeturi = originalCSSFile = ce.getAttribute("basestylesheeturi");
-						if (!basestylesheeturi.startsWith("platform:/plugin/")) {
-							basestylesheeturi = "platform:/plugin/"
-									+ ce.getContributor().getName() + "/"
-									+ basestylesheeturi;
-						}
-						final String themeBaseId = ce.getAttribute("id") + version;
+
+						final String themeBaseId = id + version;
 						String themeId = themeBaseId;
 						String label = ce.getAttribute("label");
-						String os = ce.getAttribute("os");
 						String ws = ce.getAttribute("ws");
 						if ((os != null && !os.equals(currentOS)) || (ws != null && !ws.equals(currentWS))) {
 							if (!themesToVarients.containsKey(themeBaseId)) {
@@ -167,6 +147,12 @@ public class ThemeEngine implements IThemeEngine {
 							themesToVarients.get(themeBaseId).add(themeId);
 							label = getVarientThemeLabel(label, os, ws);
 						}
+						String originalCSSFile;
+						String basestylesheeturi = originalCSSFile = ce.getAttribute("basestylesheeturi");
+						if (!basestylesheeturi.startsWith("platform:/plugin/")) {
+							basestylesheeturi = "platform:/plugin/" + ce.getContributor().getName() + "/"
+									+ basestylesheeturi;
+						}
 						registerTheme(themeId, label, basestylesheeturi, version);
 
 						//check for modified files
@@ -283,6 +269,25 @@ public class ThemeEngine implements IThemeEngine {
 		return label;
 	}
 
+	private boolean isOsVersionMatch(String osVersionList) {
+		boolean found = false;
+		String osVersion = System.getProperty("os.version");
+		if (osVersion != null) {
+			if (osVersionList != null) {
+				String[] osVersions = osVersionList.split(","); //$NON-NLS-1$
+				for (String osVersionFromTheme : osVersions) {
+					if (osVersionFromTheme != null) {
+						if (osVersion.contains(osVersionFromTheme)) {
+							found = true;
+							break;
+						}
+					}
+				}
+			}
+		}
+		return found;
+	}
+
 	@Override
 	public synchronized ITheme registerTheme(String id, String label, String basestylesheetURI)
 			throws IllegalArgumentException {
