@@ -542,7 +542,7 @@ public class MinMaxAddon {
 				ctf.setMaximizeVisible(true);
 				ctf.setMinimized(false);
 				ctf.setMaximized(false);
-				ctf.layout();
+				ctf.requestLayout();
 			}
 		}
 	}
@@ -741,7 +741,7 @@ public class MinMaxAddon {
 			}
 			if (perspStack != null) {
 				if (perspStack.getElementId() == null || perspStack.getElementId().length() == 0)
-				 {
+				{
 					perspStack.setElementId("PerspectiveStack"); //$NON-NLS-1$
 				}
 
