@@ -567,7 +567,7 @@ public class TrimStack {
 				orientation = SWT.VERTICAL;
 			}
 			// TrimStacks are draggable by default
-			 me.getTags().add(IPresentationEngine.DRAGGABLE);
+			me.getTags().add(IPresentationEngine.DRAGGABLE);
 		}
 		trimStackTB = new ToolBar(parent, orientation | SWT.FLAT | SWT.WRAP);
 		trimStackTB.addDisposeListener(e -> {
@@ -738,8 +738,7 @@ public class TrimStack {
 
 	private MUIElement findElement() {
 		MUIElement result;
-		List<MPerspectiveStack> ps = modelService.findElements(window, null,
-				MPerspectiveStack.class, null);
+		List<MPerspectiveStack> ps = modelService.findElements(window, null, MPerspectiveStack.class);
 		if (ps.isEmpty()) {
 			String toolControlId = toolControl.getElementId();
 			int index = toolControlId.indexOf('(');
@@ -754,8 +753,7 @@ public class TrimStack {
 
 			MPerspective persp = null;
 			if (perspId != null) {
-				List<MPerspective> perspectives = modelService.findElements(ps.get(0), perspId, MPerspective.class,
-						null);
+				List<MPerspective> perspectives = modelService.findElements(ps.get(0), perspId, MPerspective.class);
 				if (perspectives != null && !perspectives.isEmpty()) {
 					persp = perspectives.get(0);
 				}
