@@ -88,7 +88,6 @@ import org.eclipse.swt.widgets.Decorations;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Menu;
 import org.osgi.service.event.Event;
-import org.osgi.service.event.EventHandler;
 
 /**
  * Create a contribute part.
@@ -118,6 +117,22 @@ public class MenuManagerRenderer extends SWTPartRenderer {
 	@Inject
 	IEventBroker eventBroker;
 
+	@Inject
+	@Optional
+	private void subscribeSelectionUpdated(@UIEventTopic(UIEvents.Item.TOPIC_SELECTED) Event event) {
+		Object property = event.getProperty(UIEvents.EventTags.ELEMENT);
+		// Ensure that this event is for a MToolItem
+		if (!(property instanceof MMenuItem)) {
+			return;
+		}
+
+		MMenuItem itemModel = (MMenuItem) property;
+		IContributionItem ici = getContribution(itemModel);
+		if (ici != null) {
+			ici.update();
+		}
+	}
+
 	@Inject
 	@Optional
 	private void subscribeUIElementTopicAllRenderedVisibility(@UIEventTopic(UIEvents.UIElement.TOPIC_ALL) Event event) {
@@ -281,23 +296,10 @@ public class MenuManagerRenderer extends SWTPartRenderer {
 	}
 
 
-	private EventHandler selectionUpdater = event -> {
-		// Ensure that this event is for a MToolItem
-		if (!(event.getProperty(UIEvents.EventTags.ELEMENT) instanceof MMenuItem))
-			return;
-
-		MMenuItem itemModel = (MMenuItem) event.getProperty(UIEvents.EventTags.ELEMENT);
-		IContributionItem ici = getContribution(itemModel);
-		if (ici != null) {
-			ici.update();
-		}
-	};
-
 	private MenuManagerRendererFilter rendererFilter;
 
 	@PostConstruct
 	public void init() {
-		eventBroker.subscribe(UIEvents.Item.TOPIC_SELECTED, selectionUpdater);
 
 		context.set(MenuManagerRenderer.class, this);
 		Display display = context.get(Display.class);
@@ -330,7 +332,6 @@ public class MenuManagerRenderer extends SWTPartRenderer {
 
 	@PreDestroy
 	public void contextDisposed() {
-		eventBroker.unsubscribe(selectionUpdater);
 
 		ContextInjectionFactory.uninject(MenuManagerEventHelper.getInstance().getShowHelper(), context);
 		MenuManagerEventHelper.getInstance().setShowHelper(null);
