@@ -22,6 +22,7 @@
  *******************************************************************************/
 package org.eclipse.e4.ui.workbench.renderers.swt;
 
+import java.time.Duration;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -61,6 +62,7 @@ import org.eclipse.e4.ui.model.application.ui.menu.MToolBarSeparator;
 import org.eclipse.e4.ui.model.application.ui.menu.MToolControl;
 import org.eclipse.e4.ui.model.application.ui.menu.MToolItem;
 import org.eclipse.e4.ui.services.IServiceConstants;
+import org.eclipse.e4.ui.services.IStylingEngine;
 import org.eclipse.e4.ui.workbench.IPresentationEngine;
 import org.eclipse.e4.ui.workbench.Selector;
 import org.eclipse.e4.ui.workbench.UIEvents;
@@ -76,9 +78,11 @@ import org.eclipse.jface.action.IToolBarManager;
 import org.eclipse.jface.action.MenuManager;
 import org.eclipse.jface.action.Separator;
 import org.eclipse.jface.action.ToolBarManager;
+import org.eclipse.jface.util.Throttler;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Control;
+import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.ToolBar;
 import org.eclipse.swt.widgets.ToolItem;
 import org.eclipse.swt.widgets.Widget;
@@ -111,6 +115,12 @@ public class ToolBarManagerRenderer extends SWTPartRenderer {
 
 	private ToolItemUpdater enablementUpdater = new ToolItemUpdater();
 
+	// See Bug 536308
+	// remove disableThrottling system property in 4.11 if no problems are
+	// identified in 4.10
+	private static boolean disableThrottling = System.getProperty("bug_536308.disable.throttling") != null; //$NON-NLS-1$
+
+
 	@Inject
 	private Logger logger;
 
@@ -321,7 +331,7 @@ public class ToolBarManagerRenderer extends SWTPartRenderer {
 	@Inject
 	@Optional
 	private void subscribeTopicAppStartup(@UIEventTopic(UIEvents.UILifeCycle.APP_STARTUP_COMPLETE) Event event) {
-		List<MToolBar> toolBars = modelService.findElements(application, null, MToolBar.class, null);
+		List<MToolBar> toolBars = modelService.findElements(application, null, MToolBar.class);
 		for (MToolBar mToolBar : toolBars) {
 			if (mToolBar.getTags().contains(IPresentationEngine.HIDDEN_EXPLICITLY)) {
 				mToolBar.setVisible(false);
@@ -336,11 +346,12 @@ public class ToolBarManagerRenderer extends SWTPartRenderer {
 	@PostConstruct
 	public void init() {
 		context.set(ToolBarManagerRenderer.class, this);
+		Throttler throttler = new Throttler(Display.getDefault(), Duration.ofMillis(200),
+				() -> getUpdater().updateContributionItems(ALL_SELECTOR));
 
 		String[] vars = {
 				"org.eclipse.ui.internal.services.EvaluationService.evaluate", //$NON-NLS-1$
 				IServiceConstants.ACTIVE_CONTEXTS,
-				IServiceConstants.ACTIVE_PART,
 				IServiceConstants.ACTIVE_SELECTION,
 				IServiceConstants.ACTIVE_SHELL };
 		updateVariables.addAll(Arrays.asList(vars));
@@ -352,7 +363,14 @@ public class ToolBarManagerRenderer extends SWTPartRenderer {
 				for (String var : updateVariables) {
 					context.get(var);
 				}
-				getUpdater().updateContributionItems(ALL_SELECTOR);
+				// See Bug 536308
+				// remove disableThrottling system property in 4.11 if no problems are
+				// identified in 4.10
+				if (disableThrottling) {
+					getUpdater().updateContributionItems(ALL_SELECTOR);
+				} else {
+					throttler.throttledExec();
+				}
 				return true;
 			}
 		};
@@ -373,8 +391,16 @@ public class ToolBarManagerRenderer extends SWTPartRenderer {
 			return null;
 		}
 
+		Composite toolbarComposite = (Composite) parent;
+		// Composite which contains toolbar needs to have a separate class to allow the
+		// CSS engine to target it
+		IStylingEngine engine = getContextForParent(element).get(IStylingEngine.class);
+		if (engine != null) {
+			engine.setId(toolbarComposite, "ToolbarComposite");//$NON-NLS-1$
+		}
+
 		final MToolBar toolbarModel = (MToolBar) element;
-		ToolBar newTB = createToolbar(toolbarModel, (Composite) parent);
+		ToolBar newTB = createToolbar(toolbarModel, toolbarComposite);
 		bindWidget(element, newTB);
 		processContribution(toolbarModel, toolbarModel.getElementId());
 
@@ -387,10 +413,12 @@ public class ToolBarManagerRenderer extends SWTPartRenderer {
 
 			setCSSInfo(element, newTB);
 
+
 			boolean vertical = false;
 			MTrimBar bar = (MTrimBar) parentElement;
 			vertical = bar.getSide() == SideValue.LEFT || bar.getSide() == SideValue.RIGHT;
 			IEclipseContext parentContext = getContextForParent(element);
+
 			CSSRenderingUtils cssUtils = parentContext.get(CSSRenderingUtils.class);
 			if (cssUtils != null) {
 				MUIElement modelElement = (MUIElement) newTB.getData(AbstractPartRenderer.OWNING_ME);
