@@ -62,6 +62,7 @@ import org.eclipse.emf.ecore.EClass;
 import org.eclipse.emf.ecore.EObject;
 import org.eclipse.jface.dialogs.Dialog;
 import org.eclipse.jface.util.Geometry;
+import org.eclipse.jface.util.Util;
 import org.eclipse.jface.viewers.ArrayContentProvider;
 import org.eclipse.jface.viewers.CheckboxTableViewer;
 import org.eclipse.jface.viewers.LabelProvider;
@@ -74,7 +75,6 @@ import org.eclipse.swt.events.ShellListener;
 import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.graphics.Font;
 import org.eclipse.swt.graphics.Image;
-import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.graphics.Rectangle;
 import org.eclipse.swt.graphics.Resource;
 import org.eclipse.swt.layout.GridData;
@@ -334,7 +334,7 @@ public class WBWRenderer extends SWTPartRenderer {
 	 */
 	private boolean closeDetachedWindow(MWindow window) {
 		EPartService partService = window.getContext().get(EPartService.class);
-		List<MPart> parts = modelService.findElements(window, null, MPart.class, null);
+		List<MPart> parts = modelService.findElements(window, null, MPart.class);
 		// this saves one part at a time, not ideal but better than not saving
 		// at all
 		for (MPart part : parts) {
@@ -418,7 +418,7 @@ public class WBWRenderer extends SWTPartRenderer {
 		}
 		// Force the shell onto the display if it would be invisible otherwise
 		Display display = Display.getCurrent();
-		Monitor closestMonitor = getClosestMonitor(display, Geometry.centerPoint(modelBounds));
+		Monitor closestMonitor = Util.getClosestMonitor(display, Geometry.centerPoint(modelBounds));
 		Rectangle displayBounds = closestMonitor.getClientArea();
 		if (!modelBounds.intersects(displayBounds)) {
 			Geometry.moveInside(modelBounds, displayBounds);
@@ -469,8 +469,8 @@ public class WBWRenderer extends SWTPartRenderer {
 					Arrays.fill(response, Save.CANCEL);
 				} else {
 					Arrays.fill(response, Save.NO);
-					for (int i = 0; i < elements.length; i++) {
-						response[parts.indexOf(elements[i])] = Save.YES;
+					for (Object element : elements) {
+						response[parts.indexOf(element)] = Save.YES;
 					}
 				}
 				return response;
@@ -496,44 +496,6 @@ public class WBWRenderer extends SWTPartRenderer {
 		return newWidget;
 	}
 
-	/**
-	 * TODO: Create an API for this method and delete this version. See bug
-	 * 491273
-	 *
-	 * Returns the monitor whose client area contains the given point. If no
-	 * monitor contains the point, returns the monitor that is closest to the
-	 * point. If this is ever made public, it should be moved into a separate
-	 * utility class.
-	 *
-	 * @param toSearch
-	 *            point to find (display coordinates)
-	 * @param toFind
-	 *            point to find (display coordinates)
-	 * @return the montor closest to the given point
-	 */
-	private static Monitor getClosestMonitor(Display toSearch, Point toFind) {
-		int closest = Integer.MAX_VALUE;
-
-		Monitor[] monitors = toSearch.getMonitors();
-		Monitor result = monitors[0];
-
-		for (Monitor current : monitors) {
-			Rectangle clientArea = current.getClientArea();
-
-			if (clientArea.contains(toFind)) {
-				return current;
-			}
-
-			int distance = Geometry.distanceSquared(Geometry.centerPoint(clientArea), toFind);
-			if (distance < closest) {
-				closest = distance;
-				result = current;
-			}
-		}
-
-		return result;
-	}
-
 	private void setCloseHandler(MWindow window) {
 		IEclipseContext context = window.getContext();
 		// no direct model parent, must be a detached window
@@ -678,7 +640,7 @@ public class WBWRenderer extends SWTPartRenderer {
 		} else if (parent != null) {
 			window.setToBeRendered(false);
 			// this is a detached window, check for parts
-			if (modelService.findElements(window, null, MPart.class, null)
+			if (modelService.findElements(window, null, MPart.class)
 					.isEmpty()) {
 				// if no parts, remove it
 				if (parent instanceof MWindow) {
@@ -770,7 +732,7 @@ public class WBWRenderer extends SWTPartRenderer {
 			}
 		});
 
-		 try {
+		try {
 			// Apply the correct shell state
 			if (shellME.getTags().contains(ShellMaximizedTag)) {
 				shell.setMaximized(true);
@@ -780,13 +742,13 @@ public class WBWRenderer extends SWTPartRenderer {
 
 			shell.layout(true);
 			forceLayout(shell);
-		 } finally {
+		} finally {
 			if (shellME.isVisible()) {
 				shell.open();
 			} else {
 				shell.setVisible(false);
 			}
-		 }
+		}
 	}
 
 	private Object[] promptForSave(Shell parentShell,
