@@ -490,8 +490,7 @@ public class E4Application implements IApplication {
 
 		IExtensionRegistry registry = RegistryFactory.getRegistry();
 		ExceptionHandler exceptionHandler = new ExceptionHandler();
-		ReflectionContributionFactory contributionFactory = new ReflectionContributionFactory(registry);
-		serviceContext.set(IContributionFactory.class, contributionFactory);
+		serviceContext.set(IContributionFactory.class, new ReflectionContributionFactory());
 		serviceContext.set(IExceptionHandler.class, exceptionHandler);
 		serviceContext.set(IExtensionRegistry.class, registry);
 
@@ -683,11 +682,8 @@ public class E4Application implements IApplication {
 			// file, it happens to follow the same format currently, so using
 			// Properties to read it is convenient.
 			Properties props = new Properties();
-			FileInputStream is = new FileInputStream(versionFile);
-			try {
+			try (FileInputStream is = new FileInputStream(versionFile)) {
 				props.load(is);
-			} finally {
-				is.close();
 			}
 
 			return props.getProperty(WORKSPACE_VERSION_KEY);
