@@ -20,15 +20,15 @@ import org.eclipse.swt.custom.CLabel;
  * @since 3.3
  *
  */
-public class CLabelTextProperty extends WidgetStringValueProperty {
+public class CLabelTextProperty extends WidgetStringValueProperty<CLabel> {
 	@Override
-	String doGetStringValue(Object source) {
-		return ((CLabel) source).getText();
+	String doGetStringValue(CLabel source) {
+		return source.getText();
 	}
 
 	@Override
-	void doSetStringValue(Object source, String value) {
-		((CLabel) source).setText(value == null ? "" : value); //$NON-NLS-1$
+	void doSetStringValue(CLabel source, String value) {
+		source.setText(value == null ? "" : value); //$NON-NLS-1$
 	}
 
 	@Override
