@@ -21,7 +21,7 @@ import org.eclipse.swt.widgets.Combo;
  * @since 3.3
  *
  */
-public class ComboTextProperty extends WidgetStringValueProperty {
+public class ComboTextProperty extends WidgetStringValueProperty<Combo> {
 	/**
 	 *
 	 */
@@ -30,13 +30,13 @@ public class ComboTextProperty extends WidgetStringValueProperty {
 	}
 
 	@Override
-	String doGetStringValue(Object source) {
-		return ((Combo) source).getText();
+	String doGetStringValue(Combo source) {
+		return source.getText();
 	}
 
 	@Override
-	void doSetStringValue(Object source, String value) {
-		((Combo) source).setText(value != null ? value : ""); //$NON-NLS-1$
+	void doSetStringValue(Combo source, String value) {
+		source.setText(value != null ? value : ""); //$NON-NLS-1$
 	}
 
 	@Override
