@@ -17,18 +17,20 @@ package org.eclipse.jface.internal.databinding.swt;
 import org.eclipse.swt.widgets.Control;
 
 /**
+ * @param <S> type of the source object
+ *
  * @since 3.3
  *
  */
-public class ControlVisibleProperty extends WidgetBooleanValueProperty {
+public class ControlVisibleProperty<S extends Control> extends WidgetBooleanValueProperty<S> {
 	@Override
-	boolean doGetBooleanValue(Object source) {
-		return ((Control) source).getVisible();
+	boolean doGetBooleanValue(S source) {
+		return source.getVisible();
 	}
 
 	@Override
-	void doSetBooleanValue(Object source, boolean value) {
-		((Control) source).setVisible(value);
+	void doSetBooleanValue(S source, boolean value) {
+		source.setVisible(value);
 	}
 
 	@Override
