@@ -19,15 +19,15 @@ import org.eclipse.swt.widgets.ScrollBar;
 /**
  *
  */
-public class ScrollBarEnabledProperty extends WidgetBooleanValueProperty {
+public class ScrollBarEnabledProperty extends WidgetBooleanValueProperty<ScrollBar> {
 	@Override
-	public boolean doGetBooleanValue(Object source) {
-		return ((ScrollBar) source).getEnabled();
+	public boolean doGetBooleanValue(ScrollBar source) {
+		return source.getEnabled();
 	}
 
 	@Override
-	void doSetBooleanValue(Object source, boolean value) {
-		((ScrollBar) source).setEnabled(value);
+	void doSetBooleanValue(ScrollBar source, boolean value) {
+		source.setEnabled(value);
 	}
 
 	@Override
