@@ -19,15 +19,15 @@ import org.eclipse.swt.widgets.ToolItem;
 /**
  *
  */
-public class ToolItemEnabledProperty extends WidgetBooleanValueProperty {
+public class ToolItemEnabledProperty extends WidgetBooleanValueProperty<ToolItem> {
 	@Override
-	public boolean doGetBooleanValue(Object source) {
-		return ((ToolItem) source).getEnabled();
+	public boolean doGetBooleanValue(ToolItem source) {
+		return source.getEnabled();
 	}
 
 	@Override
-	void doSetBooleanValue(Object source, boolean value) {
-		((ToolItem) source).setEnabled(value);
+	void doSetBooleanValue(ToolItem source, boolean value) {
+		source.setEnabled(value);
 	}
 
 	@Override
