@@ -20,8 +20,8 @@ import org.eclipse.jface.databinding.swt.ISWTObservableList;
 import org.eclipse.jface.databinding.swt.IWidgetListProperty;
 import org.eclipse.swt.widgets.Widget;
 
-abstract class WidgetDelegatingListProperty extends DelegatingListProperty
-		implements IWidgetListProperty {
+abstract class WidgetDelegatingListProperty<S extends Widget, E> extends DelegatingListProperty<S, E>
+		implements IWidgetListProperty<S, E> {
 	RuntimeException notSupported(Object source) {
 		return new IllegalArgumentException(
 				"Widget [" + source.getClass().getName() + "] is not supported."); //$NON-NLS-1$//$NON-NLS-2$
@@ -32,8 +32,7 @@ abstract class WidgetDelegatingListProperty extends DelegatingListProperty
 	}
 
 	@Override
-	public ISWTObservableList observe(Widget widget) {
-		return (ISWTObservableList) observe(DisplayRealm.getRealm(widget
-				.getDisplay()), widget);
+	public ISWTObservableList<E> observe(S widget) {
+		return (ISWTObservableList<E>) observe(DisplayRealm.getRealm(widget.getDisplay()), widget);
 	}
 }
\ No newline at end of file
