@@ -17,14 +17,17 @@ package org.eclipse.jface.internal.databinding.swt;
 import org.eclipse.core.databinding.property.value.IValueProperty;
 import org.eclipse.swt.widgets.Text;
 import org.eclipse.swt.widgets.ToolTip;
+import org.eclipse.swt.widgets.Widget;
 
 /**
+ * @param <S> type of the source object
+ *
  * @since 3.3
  *
  */
-public class WidgetMessageProperty extends WidgetDelegatingValueProperty {
-	private IValueProperty text;
-	private IValueProperty toolTip;
+public class WidgetMessageProperty<S extends Widget> extends WidgetDelegatingValueProperty<S, String> {
+	private IValueProperty<S, String> text;
+	private IValueProperty<S, String> toolTip;
 
 	/**
 	 *
@@ -33,16 +36,17 @@ public class WidgetMessageProperty extends WidgetDelegatingValueProperty {
 		super(String.class);
 	}
 
+	@SuppressWarnings("unchecked")
 	@Override
-	protected IValueProperty doGetDelegate(Object source) {
+	protected IValueProperty<S, String> doGetDelegate(S source) {
 		if (source instanceof Text) {
 			if (text == null)
-				text = new TextMessageProperty();
+				text = (IValueProperty<S, String>) new TextMessageProperty();
 			return text;
 		}
 		if (source instanceof ToolTip) {
 			if (toolTip == null)
-				toolTip = new ToolTipMessageProperty();
+				toolTip = (IValueProperty<S, String>) new ToolTipMessageProperty();
 			return toolTip;
 		}
 		throw notSupported(source);
