@@ -96,7 +96,7 @@ public final class LegacyActionTools {
 	public static String convertAccelerator(final int keyCode) {
 		String modifier = getModifierString(keyCode);
 		String fullKey;
-		if (modifier.equals("")) { //$NON-NLS-1$
+		if (modifier.isEmpty()) {
 			fullKey = findKeyString(keyCode);
 		} else {
 			fullKey = modifier + "+" + findKeyString(keyCode); //$NON-NLS-1$
@@ -245,11 +245,12 @@ public final class LegacyActionTools {
 	}
 
 	/**
-	 * Maps a standard keyboard key name to an SWT key code. Key names are
-	 * converted to upper case before comparison. If the key name is a single
-	 * letter, for example "S", its character code is returned.
+	 * Maps a standard keyboard key name to an SWT key code. Key names are converted
+	 * to upper case before comparison. If the key name is a single letter, for
+	 * example "S", its character code is returned.
 	 * <p>
 	 * The following key names are known (case is ignored):
+	 * </p>
 	 * <ul>
 	 * <li><code>"BACKSPACE"</code></li>
 	 * <li><code>"TAB"</code></li>
@@ -267,10 +268,8 @@ public final class LegacyActionTools {
 	 * <li><code>"INSERT"</code></li>
 	 * <li><code>"F1"</code>, <code>"F2"</code> through <code>"F12"</code></li>
 	 * </ul>
-	 * </p>
 	 *
-	 * @param token
-	 *            the key name
+	 * @param token the key name
 	 * @return the SWT key code, <code>-1</code> if no match was found
 	 * @see SWT
 	 */
@@ -448,7 +447,7 @@ public final class LegacyActionTools {
 		}
 
 		if ((keyCode & SWT.ALT) != 0) {
-			if (modString.equals("")) { //$NON-NLS-1$
+			if (modString.isEmpty()) {
 				modString = findModifierString(keyCode & SWT.ALT);
 			} else {
 				modString = modString
@@ -457,7 +456,7 @@ public final class LegacyActionTools {
 		}
 
 		if ((keyCode & SWT.SHIFT) != 0) {
-			if (modString.equals("")) { //$NON-NLS-1$
+			if (modString.isEmpty()) {
 				modString = findModifierString(keyCode & SWT.SHIFT);
 			} else {
 				modString = modString
@@ -466,7 +465,7 @@ public final class LegacyActionTools {
 		}
 
 		if ((keyCode & SWT.COMMAND) != 0) {
-			if (modString.equals("")) { //$NON-NLS-1$
+			if (modString.isEmpty()) {
 				modString = findModifierString(keyCode & SWT.COMMAND);
 			} else {
 				modString = modString
@@ -728,11 +727,10 @@ public final class LegacyActionTools {
 
 	/**
 	 * Convenience method for removing any mnemonics from the given string. For
-	 * example, <code>removeMnemonics("&Open")</code> will return
+	 * example, <code>removeMnemonics("&amp;Open")</code> will return
 	 * <code>"Open"</code>.
 	 *
-	 * @param text
-	 *            the text
+	 * @param text the text
 	 * @return the text sans mnemonics
 	 */
 	public static String removeMnemonics(final String text) {
@@ -776,11 +774,10 @@ public final class LegacyActionTools {
 
 	/**
 	 * Convenience method for escaping all mnemonics in the given string. For
-	 * example, <code>escapeMnemonics("a & b & c")</code> will return
-	 * <code>"a && b && c"</code>.
+	 * example, <code>escapeMnemonics("a &amp; b &amp; c")</code> will return
+	 * <code>"a &amp;&amp; b &amp;&amp; c"</code>.
 	 *
-	 * @param text
-	 *            the text
+	 * @param text the text
 	 * @return the text with mnemonics escaped
 	 * @since 3.6
 	 */
