@@ -24,6 +24,10 @@ import java.util.SortedSet;
 import java.util.TreeSet;
 
 import org.eclipse.swt.SWT;
+import org.eclipse.swt.graphics.Point;
+import org.eclipse.swt.graphics.Rectangle;
+import org.eclipse.swt.widgets.Display;
+import org.eclipse.swt.widgets.Monitor;
 
 /**
  * <p>
@@ -294,23 +298,24 @@ public final class Util {
 	/**
 	 * Provides a hash code based on the given integer value.
 	 *
-	 * @param i
-	 *            The integer value
+	 * @param i The integer value
 	 * @return <code>i</code>
+	 * @deprecated return directly value, or use {@link Integer#hashCode(int)}
 	 */
+	@Deprecated
 	public static int hashCode(final int i) {
 		return i;
 	}
 
 	/**
-	 * Provides a hash code for the object -- defending against
-	 * <code>null</code>.
+	 * Provides a hash code for the object -- defending against <code>null</code>.
 	 *
-	 * @param object
-	 *            The object for which a hash code is required.
-	 * @return <code>object.hashCode</code> or <code>0</code> if
-	 *         <code>object</code> if <code>null</code>.
+	 * @param object The object for which a hash code is required.
+	 * @return <code>object.hashCode</code> or <code>0</code> if <code>object</code>
+	 *         if <code>null</code>.
+	 * @deprecated use {@link Objects#hashCode(Object)}
 	 */
+	@Deprecated
 	public static int hashCode(final Object object) {
 		return object != null ? object.hashCode() : 0;
 	}
@@ -319,12 +324,13 @@ public final class Util {
 	 * Computes the hash code for an array of objects, but with defense against
 	 * <code>null</code>.
 	 *
-	 * @param objects
-	 *            The array of objects for which a hash code is needed; may be
-	 *            <code>null</code>.
+	 * @param objects The array of objects for which a hash code is needed; may be
+	 *                <code>null</code>.
 	 * @return The hash code for <code>objects</code>; or <code>0</code> if
 	 *         <code>objects</code> is <code>null</code>.
+	 * @deprecated use {@link Arrays#hashCode(Object[])}
 	 */
+	@Deprecated
 	public static int hashCode(final Object[] objects) {
 		if (objects == null) {
 			return 0;
@@ -439,19 +445,19 @@ public final class Util {
 		return defaultString;
 	}
 
-    /**
-     * Foundation replacement for <code>String#replaceAll(String,
-     * String)</code>, but <strong>without support for regular
-     * expressions</strong>.
-     *
-     * @param src the original string
-     * @param find the string to find
-     * @param replacement the replacement string
-     * @return the new string, with all occurrences of <code>find</code>
-     *         replaced by <code>replacement</code> (not using regular
-     *         expressions)
-     * @since 3.4
-     */
+	/**
+	 * Foundation replacement for <code>String#replaceAll(String,
+	 * String)</code>, but <strong>without support for regular
+	 * expressions</strong>.
+	 *
+	 * @param src the original string
+	 * @param find the string to find
+	 * @param replacement the replacement string
+	 * @return the new string, with all occurrences of <code>find</code>
+	 *         replaced by <code>replacement</code> (not using regular
+	 *         expressions)
+	 * @since 3.4
+	 */
 	public static String replaceAll(String src, String find, String replacement) {
 		final int len = src.length();
 		final int findLen = find.length();
@@ -494,6 +500,7 @@ public final class Util {
 	 * Windowing system constant.
 	 * @since 3.5
 	 */
+	@Deprecated
 	public static final String WS_MOTIF = "motif";//$NON-NLS-1$
 
 	/**
@@ -506,12 +513,14 @@ public final class Util {
 	 * Windowing system constant.
 	 * @since 3.5
 	 */
+	@Deprecated
 	public static final String WS_PHOTON = "photon";//$NON-NLS-1$
 
 	/**
 	 * Windowing system constant.
 	 * @since 3.5
 	 */
+	@Deprecated
 	public static final String WS_CARBON = "carbon";//$NON-NLS-1$
 
 	/**
@@ -559,7 +568,7 @@ public final class Util {
 	 */
 	public static boolean isLinux() {
 		final String ws = SWT.getPlatform();
-		return WS_GTK.equals(ws) || WS_MOTIF.equals(ws);
+		return WS_GTK.equals(ws);
 	}
 
 	/**
@@ -577,6 +586,7 @@ public final class Util {
 	 * @return <code>true</code> for motif platforms
 	 * @since 3.5
 	 */
+	@Deprecated
 	public static boolean isMotif() {
 		final String ws = SWT.getPlatform();
 		return WS_MOTIF.equals(ws);
@@ -587,6 +597,7 @@ public final class Util {
 	 * @return <code>true</code> for photon platforms
 	 * @since 3.5
 	 */
+	@Deprecated
 	public static boolean isPhoton() {
 		final String ws = SWT.getPlatform();
 		return WS_PHOTON.equals(ws);
@@ -597,6 +608,7 @@ public final class Util {
 	 * @return <code>true</code> for carbon platforms
 	 * @since 3.5
 	 */
+	@Deprecated
 	public static boolean isCarbon() {
 		final String ws = SWT.getPlatform();
 		return WS_CARBON.equals(ws);
@@ -648,4 +660,37 @@ public final class Util {
 	private Util() {
 		// Not allowed.
 	}
+
+	/**
+	 * Returns the monitor whose client area contains the given point. If no monitor
+	 * contains the point, returns the monitor that is closest to the point. If this
+	 * is ever made public, it should be moved into a separate utility class.
+	 *
+	 * @param toSearch point to find (display coordinates)
+	 * @param toFind   point to find (display coordinates)
+	 * @return the monitor closest to the given point
+	 * @since 3.15
+	 */
+	public static Monitor getClosestMonitor(Display toSearch, Point toFind) {
+		int closest = Integer.MAX_VALUE;
+
+		Monitor[] monitors = toSearch.getMonitors();
+		Monitor result = monitors[0];
+
+		for (Monitor current : monitors) {
+			Rectangle clientArea = current.getClientArea();
+
+			if (clientArea.contains(toFind)) {
+				return current;
+			}
+
+			int distance = Geometry.distanceSquared(Geometry.centerPoint(clientArea), toFind);
+			if (distance < closest) {
+				closest = distance;
+				result = current;
+			}
+		}
+
+		return result;
+	}
 }
