@@ -66,7 +66,7 @@ import org.eclipse.swt.widgets.Widget;
  * <p>
  * <strong> This class is not intended to be subclassed outside of the JFace
  * viewers framework.</strong>
- * <p>
+ * </p>
  *
  * @see TreeViewer
  */
@@ -373,8 +373,7 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 		// Count of elements we have added. See bug 205700 for why this is needed.
 		int newItems = 0;
 
-		elementloop: for (int i = 0; i < elements.length; i++) {
-			Object element = elements[i];
+		elementloop: for (Object element : elements) {
 			// update the index relative to the original item array
 			indexInItems = insertionPosition(items, comparator,
 					indexInItems, element, parentPath);
@@ -989,9 +988,8 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 
 		// Go through the items of the current collection
 		// If there is a mismatch return false
-		for (int i = 0; i < current.length; i++) {
-			if (current[i].getData() == null
-					|| !itemSet.containsKey(current[i].getData())) {
+		for (Item c : current) {
+			if (c.getData() == null || !itemSet.containsKey(c.getData())) {
 				return false;
 			}
 		}
@@ -1563,15 +1561,15 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	@Override
 	protected void inputChanged(Object input, Object oldInput) {
 		preservingSelection(() -> {
-		    Control tree = getControl();
-		    tree.setRedraw(false);
-		    try {
-		        removeAll(tree);
-		        tree.setData(getRoot());
-		        internalInitializeTree(tree);
-		    } finally {
-		        tree.setRedraw(true);
-		    }
+			Control tree = getControl();
+			tree.setRedraw(false);
+			try {
+				removeAll(tree);
+				tree.setData(getRoot());
+				internalInitializeTree(tree);
+			} finally {
+				tree.setRedraw(true);
+			}
 		});
 	}
 
@@ -1591,15 +1589,13 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	 * Recursively collapses the subtree rooted at the given widget to the given
 	 * level.
 	 * <p>
-	 * </p>
 	 * Note that the default implementation of this method does not call
 	 * <code>setRedraw</code>.
+	 * </p>
 	 *
-	 * @param widget
-	 *            the widget
-	 * @param level
-	 *            non-negative level, or <code>ALL_LEVELS</code> to collapse
-	 *            all levels of the tree
+	 * @param widget the widget
+	 * @param level  non-negative level, or <code>ALL_LEVELS</code> to collapse all
+	 *               levels of the tree
 	 */
 	protected void internalCollapseToLevel(Widget widget, int level) {
 		if (level == ALL_LEVELS || level > 0) {
@@ -1784,15 +1780,13 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	 * Recursively expands the subtree rooted at the given widget to the given
 	 * level.
 	 * <p>
-	 * </p>
 	 * Note that the default implementation of this method does not call
 	 * <code>setRedraw</code>.
+	 * </p>
 	 *
-	 * @param widget
-	 *            the widget
-	 * @param level
-	 *            non-negative level, or <code>ALL_LEVELS</code> to collapse
-	 *            all levels of the tree
+	 * @param widget the widget
+	 * @param level  non-negative level, or <code>ALL_LEVELS</code> to collapse all
+	 *               levels of the tree
 	 */
 	protected void internalExpandToLevel(Widget widget, int level) {
 		if (level == ALL_LEVELS || level > 0) {
