@@ -20,6 +20,7 @@ import org.eclipse.jface.resource.JFaceResources;
 import org.eclipse.jface.util.Geometry;
 import org.eclipse.jface.util.IPropertyChangeListener;
 import org.eclipse.jface.util.PropertyChangeEvent;
+import org.eclipse.jface.util.Util;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.ShellAdapter;
 import org.eclipse.swt.events.ShellEvent;
@@ -41,15 +42,16 @@ import org.eclipse.swt.widgets.Shell;
  * until it is told to open.
  * <p>
  * Creating a window involves the following steps:
+ * </p>
  * <ul>
- * <li>creating an instance of a concrete subclass of <code>Window</code>
- * </li>
+ * <li>creating an instance of a concrete subclass of <code>Window</code></li>
  * <li>creating the window's shell and widget tree by calling
  * <code>create</code> (optional)</li>
  * <li>assigning the window to a window manager using
  * <code>WindowManager.add</code> (optional)</li>
  * <li>opening the window by calling <code>open</code></li>
  * </ul>
+ * <p>
  * Opening the window will create its shell and widget tree if they have not
  * already been created. When the window is closed, the shell and widget tree
  * are disposed of and are no longer referenced, and the window is automatically
@@ -58,30 +60,30 @@ import org.eclipse.swt.widgets.Shell;
  * <p>
  * The JFace window framework (this package) consists of this class,
  * <code>Window</code>, the abstract base of all windows, and one concrete
- * window classes (<code>ApplicationWindow</code>) which may also be
- * subclassed. Clients may define additional window subclasses as required.
+ * window classes (<code>ApplicationWindow</code>) which may also be subclassed.
+ * Clients may define additional window subclasses as required.
  * </p>
  * <p>
- * The <code>Window</code> class provides methods that subclasses may
- * override to configure the window, including:
+ * The <code>Window</code> class provides methods that subclasses may override
+ * to configure the window, including:
+ * </p>
  * <ul>
  * <li><code>close</code>- extend to free other SWT resources</li>
  * <li><code>configureShell</code>- extend or reimplement to set shell
  * properties before window opens</li>
  * <li><code>createContents</code>- extend or reimplement to create controls
  * before window opens</li>
- * <li><code>getInitialSize</code>- reimplement to give the initial size for
- * the shell</li>
- * <li><code>getInitialLocation</code>- reimplement to give the initial
- * location for the shell</li>
+ * <li><code>getInitialSize</code>- reimplement to give the initial size for the
+ * shell</li>
+ * <li><code>getInitialLocation</code>- reimplement to give the initial location
+ * for the shell</li>
  * <li><code>getShellListener</code>- extend or reimplement to receive shell
  * events</li>
  * <li><code>handleFontChange</code>- reimplement to respond to font changes
  * </li>
- * <li><code>handleShellCloseEvent</code>- extend or reimplement to handle
- * shell closings</li>
+ * <li><code>handleShellCloseEvent</code>- extend or reimplement to handle shell
+ * closings</li>
  * </ul>
- * </p>
  */
 public abstract class Window implements IShellProvider {
 
@@ -149,31 +151,31 @@ public abstract class Window implements IShellProvider {
 	 */
 	private static int orientation = SWT.NONE;
 
-    /**
-     * Object used to locate the default parent for modal shells
-     */
-    private static IShellProvider defaultModalParent = () -> {
-	    Display d = Display.getCurrent();
+	/**
+	 * Object used to locate the default parent for modal shells
+	 */
+	private static IShellProvider defaultModalParent = () -> {
+		Display d = Display.getCurrent();
 
-	    if (d == null) {
-	        return null;
-	    }
+		if (d == null) {
+			return null;
+		}
 
-	    Shell parent = d.getActiveShell();
+		Shell parent = d.getActiveShell();
 
-	    // Make sure we don't pick a parent that has a modal child (this can lock the app)
-	    if (parent == null) {
-	        // If this is a top-level window, then there must not be any open modal windows.
-	        parent = getModalChild(Display.getCurrent().getShells());
-	    } else {
-	        // If we picked a parent with a modal child, use the modal child instead
-	        Shell modalChild = getModalChild(parent.getShells());
-	        if (modalChild != null) {
-	            parent = modalChild;
-	        }
-	    }
+		// Make sure we don't pick a parent that has a modal child (this can lock the app)
+		if (parent == null) {
+			// If this is a top-level window, then there must not be any open modal windows.
+			parent = getModalChild(Display.getCurrent().getShells());
+		} else {
+			// If we picked a parent with a modal child, use the modal child instead
+			Shell modalChild = getModalChild(parent.getShells());
+			if (modalChild != null) {
+				parent = modalChild;
+			}
+		}
 
-	    return parent;
+		return parent;
 	};
 
 	/**
@@ -253,30 +255,30 @@ public abstract class Window implements IShellProvider {
 	 * @param parentShell
 	 *            the parent shell, or <code>null</code> to create a top-level
 	 *            shell. Try passing "(Shell)null" to this method instead of "null"
-     *            if your compiler complains about an ambiguity error.
+	 *            if your compiler complains about an ambiguity error.
 	 * @see #setBlockOnOpen
 	 * @see #getDefaultOrientation()
 	 */
 	protected Window(Shell parentShell) {
-        this(new SameShellProvider(parentShell));
+		this(new SameShellProvider(parentShell));
 
-        if(parentShell == null) {
+		if(parentShell == null) {
 			setShellStyle(getShellStyle() | getDefaultOrientation());
 		}
 	}
 
-    /**
-     * Creates a new window which will create its shell as a child of whatever
-     * the given shellProvider returns.
-     *
-     * @param shellProvider object that will return the current parent shell. Not null.
-     *
-     * @since 3.1
-     */
-    protected Window(IShellProvider shellProvider) {
-        Assert.isNotNull(shellProvider);
-        this.parentShell = shellProvider;
-    }
+	/**
+	 * Creates a new window which will create its shell as a child of whatever
+	 * the given shellProvider returns.
+	 *
+	 * @param shellProvider object that will return the current parent shell. Not null.
+	 *
+	 * @since 3.1
+	 */
+	protected Window(IShellProvider shellProvider) {
+		Assert.isNotNull(shellProvider);
+		this.parentShell = shellProvider;
+	}
 
 	/**
 	 * Determines if the window should handle the close event or do nothing.
@@ -588,35 +590,35 @@ public abstract class Window implements IShellProvider {
 		return shell.computeSize(SWT.DEFAULT, SWT.DEFAULT, true);
 	}
 
-    /**
-     * Returns the most specific modal child from the given list of Shells.
-     *
-     * @param toSearch shells to search for modal children
-     * @return the most specific modal child, or null if none
-     *
-     * @since 3.1
-     */
-    private static Shell getModalChild(Shell[] toSearch) {
-        int modal = SWT.APPLICATION_MODAL | SWT.SYSTEM_MODAL | SWT.PRIMARY_MODAL;
+	/**
+	 * Returns the most specific modal child from the given list of Shells.
+	 *
+	 * @param toSearch shells to search for modal children
+	 * @return the most specific modal child, or null if none
+	 *
+	 * @since 3.1
+	 */
+	private static Shell getModalChild(Shell[] toSearch) {
+		int modal = SWT.APPLICATION_MODAL | SWT.SYSTEM_MODAL | SWT.PRIMARY_MODAL;
 
-        for (int i = toSearch.length - 1; i >= 0; i--) {
-            Shell shell = toSearch[i];
+		for (int i = toSearch.length - 1; i >= 0; i--) {
+			Shell shell = toSearch[i];
 
-            // Check if this shell has a modal child
-            Shell[] children = shell.getShells();
-            Shell modalChild = getModalChild(children);
-            if (modalChild != null) {
-                return modalChild;
-            }
+			// Check if this shell has a modal child
+			Shell[] children = shell.getShells();
+			Shell modalChild = getModalChild(children);
+			if (modalChild != null) {
+				return modalChild;
+			}
 
-            // If not, check if this shell is modal itself
-            if (shell.isVisible() && (shell.getStyle() & modal) != 0) {
-                return shell;
-            }
-        }
+			// If not, check if this shell is modal itself
+			if (shell.isVisible() && (shell.getStyle() & modal) != 0) {
+				return shell;
+			}
+		}
 
-        return null;
-    }
+		return null;
+	}
 
 	/**
 	 * Returns parent shell, under which this window's shell is created.
@@ -625,18 +627,18 @@ public abstract class Window implements IShellProvider {
 	 *         shell
 	 */
 	protected Shell getParentShell() {
-        Shell parent = parentShell.getShell();
+		Shell parent = parentShell.getShell();
 
-        int modal = SWT.APPLICATION_MODAL | SWT.SYSTEM_MODAL | SWT.PRIMARY_MODAL;
+		int modal = SWT.APPLICATION_MODAL | SWT.SYSTEM_MODAL | SWT.PRIMARY_MODAL;
 
-        if ((getShellStyle() & modal) != 0) {
-            // If this is a modal shell with no parent, pick a shell using defaultModalParent.
-            if (parent == null) {
-                parent = defaultModalParent.getShell();
-            }
-        }
+		if ((getShellStyle() & modal) != 0) {
+			// If this is a modal shell with no parent, pick a shell using defaultModalParent.
+			if (parent == null) {
+				parent = defaultModalParent.getShell();
+			}
+		}
 
-        return parent;
+		return parent;
 	}
 
 	/**
@@ -781,7 +783,7 @@ public abstract class Window implements IShellProvider {
 	public int open() {
 
 		if (shell == null || shell.isDisposed()) {
-            shell = null;
+			shell = null;
 			// create the window
 			create();
 		}
@@ -871,19 +873,19 @@ public abstract class Window implements IShellProvider {
 	}
 
 	/**
-     * Changes the parent shell. This is only safe to use when the shell is not
-     * yet realized (i.e., created). Once the shell is created, it must be
-     * disposed (i.e., closed) before this method can be called.
-     *
-     * @param newParentShell
-     *            The new parent shell; this value may be <code>null</code> if
-     *            there is to be no parent.
-     * @since 3.1
-     */
-    protected void setParentShell(final Shell newParentShell) {
-        Assert.isTrue((shell == null), "There must not be an existing shell."); //$NON-NLS-1$
-        parentShell = new SameShellProvider(newParentShell);
-    }
+	 * Changes the parent shell. This is only safe to use when the shell is not
+	 * yet realized (i.e., created). Once the shell is created, it must be
+	 * disposed (i.e., closed) before this method can be called.
+	 *
+	 * @param newParentShell
+	 *            The new parent shell; this value may be <code>null</code> if
+	 *            there is to be no parent.
+	 * @since 3.1
+	 */
+	protected void setParentShell(final Shell newParentShell) {
+		Assert.isTrue((shell == null), "There must not be an existing shell."); //$NON-NLS-1$
+		parentShell = new SameShellProvider(newParentShell);
+	}
 
 	/**
 	 * Sets this window's return code. The return code is automatically returned
@@ -898,41 +900,6 @@ public abstract class Window implements IShellProvider {
 		returnCode = code;
 	}
 
-	/**
-	 * Returns the monitor whose client area contains the given point. If no
-	 * monitor contains the point, returns the monitor that is closest to the
-	 * point. If this is ever made public, it should be moved into a separate
-	 * utility class.
-	 *
-	 * @param toSearch
-	 *            point to find (display coordinates)
-	 * @param toFind
-	 *            point to find (display coordinates)
-	 * @return the monitor closest to the given point
-	 */
-	private static Monitor getClosestMonitor(Display toSearch, Point toFind) {
-		int closest = Integer.MAX_VALUE;
-
-		Monitor[] monitors = toSearch.getMonitors();
-		Monitor result = monitors[0];
-
-		for (Monitor current : monitors) {
-			Rectangle clientArea = current.getClientArea();
-
-			if (clientArea.contains(toFind)) {
-				return current;
-			}
-
-			int distance = Geometry.distanceSquared(Geometry
-					.centerPoint(clientArea), toFind);
-			if (distance < closest) {
-				closest = distance;
-				result = current;
-			}
-		}
-
-		return result;
-	}
 
 	/**
 	 * Given the desired position of the window, this method returns an adjusted
@@ -952,7 +919,7 @@ public abstract class Window implements IShellProvider {
 		Rectangle result = new Rectangle(preferredSize.x, preferredSize.y,
 				preferredSize.width, preferredSize.height);
 
-		Monitor mon = getClosestMonitor(getShell().getDisplay(), Geometry
+		Monitor mon = Util.getClosestMonitor(getShell().getDisplay(), Geometry
 				.centerPoint(result));
 
 		Rectangle bounds = mon.getClientArea();
@@ -1030,17 +997,17 @@ public abstract class Window implements IShellProvider {
 		}
 	}
 
-    /**
-     * Sets the default parent for modal Windows. This will be used to locate
-     * the parent for any modal Window constructed with a null parent.
-     *
-     * @param provider shell provider that will be used to locate the parent shell
-     * whenever a Window is created with a null parent
-     * @since 3.1
-     */
-    public static void setDefaultModalParent(IShellProvider provider) {
-        defaultModalParent = provider;
-    }
+	/**
+	 * Sets the default parent for modal Windows. This will be used to locate
+	 * the parent for any modal Window constructed with a null parent.
+	 *
+	 * @param provider shell provider that will be used to locate the parent shell
+	 * whenever a Window is created with a null parent
+	 * @since 3.1
+	 */
+	public static void setDefaultModalParent(IShellProvider provider) {
+		defaultModalParent = provider;
+	}
 
 	/**
 	 * Gets the default orientation for windows. If it is not
