@@ -527,9 +527,11 @@ public class IDEWorkbenchMessages extends NLS {
 	public static String WorkbenchPreference_encoding_encodingMessage;
 
 	public static String UriHandlerPreferencePage_Warning_OtherApp;
-
 	public static String UriHandlerPreferencePage_Warning_OtherApp_Description;
 
+	public static String UriHandlerPreferencePage_Warning_OtherApp_Confirmation;
+	public static String UriHandlerPreferencePage_Warning_OtherApp_Confirmation_Description;
+
 	// --- Link Handler Preference Page ---
 	public static String UrlHandlerPreferencePage_Handler_Label;
 	public static String UrlHandlerPreferencePage_Handler_Text_No_Application;
@@ -539,8 +541,11 @@ public class IDEWorkbenchMessages extends NLS {
 	public static String UrlHandlerPreferencePage_ColumnName_Handler;
 	public static String UrlHandlerPreferencePage_Column_Handler_Text_Current_Application;
 	public static String UrlHandlerPreferencePage_Column_Handler_Text_Other_Application;
+	public static String UriHandlerPreferencePage_Confirm_Handle;
 	public static String UrlHandlerPreferencePage_Error_Reading_Scheme;
 	public static String UrlHandlerPreferencePage_Error_Writing_Scheme;
+	public static String UrlHandlerPreferencePage_UnsupportedOperatingSystem;
+	public static String UrlHandlerPreferencePage_LauncherCannotBeDetermined;
 
 	// ---workspace ---
 	public static String IDEWorkspacePreference_autobuild;
@@ -1059,7 +1064,7 @@ public class IDEWorkbenchMessages extends NLS {
 	public static String IDEEncoding_EncodingJob;
 	public static String IDEEditorsPreferencePage_WorkbenchPreference_viewsRelatedLink;
 	public static String IDEEditorsPreferencePage_WorkbenchPreference_FileEditorsRelatedLink;
-    public static String IDEEditorsPreferencePage_WorkbenchPreference_contentTypesRelatedLink;
+	public static String IDEEditorsPreferencePage_WorkbenchPreference_contentTypesRelatedLink;
 	public static String WorkbenchEncoding_invalidCharset;
 	public static String CopyProjectAction_confirm;
 	public static String CopyProjectAction_warning;
