@@ -90,38 +90,38 @@ import org.eclipse.ui.progress.IProgressConstants2;
  */
 public class CleanDialog extends MessageDialog {
 
-    private static class ProjectSubsetBuildAction extends BuildAction {
+	private static class ProjectSubsetBuildAction extends BuildAction {
 
-        private IProject[] projectsToBuild = new IProject[0];
+		private IProject[] projectsToBuild = new IProject[0];
 
-        public ProjectSubsetBuildAction(IShellProvider shellProvider, int type, IProject[] projects) {
-            super(shellProvider, type);
-            this.projectsToBuild = projects;
-        }
+		public ProjectSubsetBuildAction(IShellProvider shellProvider, int type, IProject[] projects) {
+			super(shellProvider, type);
+			this.projectsToBuild = projects;
+		}
 
-        @Override
+		@Override
 		protected List<? extends IResource> getSelectedResources() {
-            return Arrays.asList(this.projectsToBuild);
-        }
+			return Arrays.asList(this.projectsToBuild);
+		}
 	}
 
-    private static final String DIALOG_SETTINGS_SECTION = "CleanDialogSettings"; //$NON-NLS-1$
-    private static final String DIALOG_ORIGIN_X = "DIALOG_X_ORIGIN"; //$NON-NLS-1$
-    private static final String DIALOG_ORIGIN_Y = "DIALOG_Y_ORIGIN"; //$NON-NLS-1$
-    private static final String DIALOG_WIDTH = "DIALOG_WIDTH"; //$NON-NLS-1$
-    private static final String DIALOG_HEIGHT = "DIALOG_HEIGHT"; //$NON-NLS-1$
+	private static final String DIALOG_SETTINGS_SECTION = "CleanDialogSettings"; //$NON-NLS-1$
+	private static final String DIALOG_ORIGIN_X = "DIALOG_X_ORIGIN"; //$NON-NLS-1$
+	private static final String DIALOG_ORIGIN_Y = "DIALOG_Y_ORIGIN"; //$NON-NLS-1$
+	private static final String DIALOG_WIDTH = "DIALOG_WIDTH"; //$NON-NLS-1$
+	private static final String DIALOG_HEIGHT = "DIALOG_HEIGHT"; //$NON-NLS-1$
 	private static final String TOGGLE_SELECTED = "TOGGLE_SELECTED"; //$NON-NLS-1$
-    private static final String BUILD_NOW = "BUILD_NOW"; //$NON-NLS-1$
-    private static final String BUILD_ALL = "BUILD_ALL"; //$NON-NLS-1$
+	private static final String BUILD_NOW = "BUILD_NOW"; //$NON-NLS-1$
+	private static final String BUILD_ALL = "BUILD_ALL"; //$NON-NLS-1$
 
 	private Button alwaysCleanButton, buildNowButton, globalBuildButton,
 			projectBuildButton;
 
-    private CheckboxTableViewer projectNames;
+	private CheckboxTableViewer projectNames;
 
-    private Object[] selection;
+	private Object[] selection;
 
-    private IWorkbenchWindow window;
+	private IWorkbenchWindow window;
 
 	private Text filterText;
 	private SearchPattern searchPattern = new SearchPattern();
@@ -153,99 +153,99 @@ public class CleanDialog extends MessageDialog {
 		}
 	}
 
-    /**
-     * Gets the text of the clean dialog, depending on whether the
-     * workspace is currently in autobuild mode.
-     * @return String the question the user will be asked.
-     */
-    private static String getQuestion() {
-        boolean autoBuilding = ResourcesPlugin.getWorkspace().isAutoBuilding();
-        if (autoBuilding) {
-            return IDEWorkbenchMessages.CleanDialog_buildCleanAuto;
-        }
-        return IDEWorkbenchMessages.CleanDialog_buildCleanManual;
-    }
+	/**
+	 * Gets the text of the clean dialog, depending on whether the
+	 * workspace is currently in autobuild mode.
+	 * @return String the question the user will be asked.
+	 */
+	private static String getQuestion() {
+		boolean autoBuilding = ResourcesPlugin.getWorkspace().isAutoBuilding();
+		if (autoBuilding) {
+			return IDEWorkbenchMessages.CleanDialog_buildCleanAuto;
+		}
+		return IDEWorkbenchMessages.CleanDialog_buildCleanManual;
+	}
 
-    /**
-     * Creates a new clean dialog.
-     *
-     * @param window the window to create it in
-     * @param selection the currently selected projects (may be empty)
-     */
-    public CleanDialog(IWorkbenchWindow window, IProject[] selection) {
+	/**
+	 * Creates a new clean dialog.
+	 *
+	 * @param window the window to create it in
+	 * @param selection the currently selected projects (may be empty)
+	 */
+	public CleanDialog(IWorkbenchWindow window, IProject[] selection) {
 		super(window.getShell(), IDEWorkbenchMessages.CleanDialog_title, null, getQuestion(), NONE, 0,
 				IDEWorkbenchMessages.CleanDialog_clean_button_label, IDialogConstants.CANCEL_LABEL);
-        this.window = window;
-        this.selection = selection;
-        if (this.selection == null) {
-            this.selection = new Object[0];
-        }
+		this.window = window;
+		this.selection = selection;
+		if (this.selection == null) {
+			this.selection = new Object[0];
+		}
 		searchPattern.setPattern(""); //$NON-NLS-1$
-    }
+	}
 
-    @Override
+	@Override
 	protected void buttonPressed(int buttonId) {
 		final boolean cleanAll = alwaysCleanButton.getSelection();
 		final boolean buildAll = buildNowButton != null && buildNowButton.getSelection();
 		final boolean globalBuild = globalBuildButton != null && globalBuildButton.getSelection();
-        super.buttonPressed(buttonId);
-        if (buttonId != IDialogConstants.OK_ID) {
-            return;
-        }
-        //save all dirty editors
-        BuildUtilities.saveEditors(null);
-        //batching changes ensures that autobuild runs after cleaning
+		super.buttonPressed(buttonId);
+		if (buttonId != IDialogConstants.OK_ID) {
+			return;
+		}
+		//save all dirty editors
+		BuildUtilities.saveEditors(null);
+		//batching changes ensures that autobuild runs after cleaning
 		WorkspaceJob cleanJob = new WorkspaceJob(
 				cleanAll ? IDEWorkbenchMessages.CleanDialog_cleanAllTaskName
 						: IDEWorkbenchMessages.CleanDialog_cleanSelectedTaskName) {
-            @Override
+			@Override
 			public boolean belongsTo(Object family) {
-                return ResourcesPlugin.FAMILY_MANUAL_BUILD.equals(family);
-            }
-            @Override
+				return ResourcesPlugin.FAMILY_MANUAL_BUILD.equals(family);
+			}
+			@Override
 			public IStatus runInWorkspace(IProgressMonitor monitor) throws CoreException {
-                doClean(cleanAll, monitor);
-                //see if a build was requested
-                if (buildAll) {
-                    // Only build what was requested
-                    if (globalBuild) {
-                        //start an immediate workspace build
+				doClean(cleanAll, monitor);
+				//see if a build was requested
+				if (buildAll) {
+					// Only build what was requested
+					if (globalBuild) {
+						//start an immediate workspace build
 						GlobalBuildAction build = new GlobalBuildAction(window,
 								IncrementalProjectBuilder.INCREMENTAL_BUILD);
-                        build.doBuild();
-                    } else {
-                        // Only build what was cleaned
-                        IProject[] projects = new IProject[selection.length];
-                        for (int i = 0; i < selection.length; i++) {
-                            projects[i] = (IProject) selection[i];
-                        }
+						build.doBuild();
+					} else {
+						// Only build what was cleaned
+						IProject[] projects = new IProject[selection.length];
+						for (int i = 0; i < selection.length; i++) {
+							projects[i] = (IProject) selection[i];
+						}
 
-                        ProjectSubsetBuildAction projectBuild =
-                            new ProjectSubsetBuildAction(window,
-                                IncrementalProjectBuilder.INCREMENTAL_BUILD,
-                                projects);
-                        projectBuild.runInBackground(
-                                ResourcesPlugin.getWorkspace().getRuleFactory().buildRule());
-                    }
-                }
-                return Status.OK_STATUS;
-            }
-        };
+						ProjectSubsetBuildAction projectBuild =
+							new ProjectSubsetBuildAction(window,
+								IncrementalProjectBuilder.INCREMENTAL_BUILD,
+								projects);
+						projectBuild.runInBackground(
+								ResourcesPlugin.getWorkspace().getRuleFactory().buildRule());
+					}
+				}
+				return Status.OK_STATUS;
+			}
+		};
 		cleanJob.setRule(ResourcesPlugin.getWorkspace().getRuleFactory().buildRule());
-        cleanJob.setUser(true);
-        cleanJob.setProperty(IProgressConstants2.SHOW_IN_TASKBAR_ICON_PROPERTY, Boolean.TRUE);
-        cleanJob.schedule();
-    }
+		cleanJob.setUser(true);
+		cleanJob.setProperty(IProgressConstants2.SHOW_IN_TASKBAR_ICON_PROPERTY, Boolean.TRUE);
+		cleanJob.schedule();
+	}
 
-    @Override
+	@Override
 	protected Control createCustomArea(Composite parent) {
-        Composite area = new Composite(parent, SWT.NONE);
-        GridLayout areaLayout = new GridLayout();
-        areaLayout.marginWidth = areaLayout.marginHeight = 0;
+		Composite area = new Composite(parent, SWT.NONE);
+		GridLayout areaLayout = new GridLayout();
+		areaLayout.marginWidth = areaLayout.marginHeight = 0;
 		areaLayout.numColumns = 1;
 		areaLayout.makeColumnsEqualWidth = false;
-        area.setLayout(areaLayout);
-        area.setLayoutData(new GridData(GridData.FILL_BOTH));
+		area.setLayout(areaLayout);
+		area.setLayoutData(new GridData(GridData.FILL_BOTH));
 
 		IDialogSettings settings = getDialogSettings(DIALOG_SETTINGS_SECTION);
 
@@ -321,41 +321,41 @@ public class CleanDialog extends MessageDialog {
 			setInitialFilterText();
 		}
 
-        //only prompt for immediate build if autobuild is off
-        if (!ResourcesPlugin.getWorkspace().isAutoBuilding()) {
+		//only prompt for immediate build if autobuild is off
+		if (!ResourcesPlugin.getWorkspace().isAutoBuilding()) {
 			SelectionListener updateEnablement = widgetSelectedAdapter(e -> updateEnablement());
 
-            buildNowButton = new Button(parent, SWT.CHECK);
-            buildNowButton.setText(IDEWorkbenchMessages.CleanDialog_buildNowButton);
-            String buildNow = settings.get(BUILD_NOW);
-            buildNowButton.setSelection(buildNow == null || Boolean.valueOf(buildNow).booleanValue());
+			buildNowButton = new Button(parent, SWT.CHECK);
+			buildNowButton.setText(IDEWorkbenchMessages.CleanDialog_buildNowButton);
+			String buildNow = settings.get(BUILD_NOW);
+			buildNowButton.setSelection(buildNow == null || Boolean.parseBoolean(buildNow));
 			buildNowButton.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
-            buildNowButton.addSelectionListener(updateEnablement);
+			buildNowButton.addSelectionListener(updateEnablement);
 
-            globalBuildButton = new Button(parent, SWT.RADIO);
-            globalBuildButton.setText(IDEWorkbenchMessages.CleanDialog_globalBuildButton);
-            String buildAll = settings.get(BUILD_ALL);
-            globalBuildButton.setSelection(buildAll == null || Boolean.valueOf(buildAll).booleanValue());
-            GridData data = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
-            data.horizontalIndent = 10;
-            globalBuildButton.setLayoutData(data);
-            globalBuildButton.setEnabled(buildNowButton.getSelection());
+			globalBuildButton = new Button(parent, SWT.RADIO);
+			globalBuildButton.setText(IDEWorkbenchMessages.CleanDialog_globalBuildButton);
+			String buildAll = settings.get(BUILD_ALL);
+			globalBuildButton.setSelection(buildAll == null || Boolean.parseBoolean(buildAll));
+			GridData data = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
+			data.horizontalIndent = 10;
+			globalBuildButton.setLayoutData(data);
+			globalBuildButton.setEnabled(buildNowButton.getSelection());
 
-            projectBuildButton = new Button(parent, SWT.RADIO);
-            projectBuildButton.setText(IDEWorkbenchMessages.CleanDialog_buildSelectedProjectsButton);
-            projectBuildButton.setSelection(!globalBuildButton.getSelection());
-            data = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
-            data.horizontalIndent = 10;
-            projectBuildButton.setLayoutData(data);
-            projectBuildButton.setEnabled(buildNowButton.getSelection());
+			projectBuildButton = new Button(parent, SWT.RADIO);
+			projectBuildButton.setText(IDEWorkbenchMessages.CleanDialog_buildSelectedProjectsButton);
+			projectBuildButton.setSelection(!globalBuildButton.getSelection());
+			data = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
+			data.horizontalIndent = 10;
+			projectBuildButton.setLayoutData(data);
+			projectBuildButton.setEnabled(buildNowButton.getSelection());
 
 			SelectionListener buildRadioSelected = widgetSelectedAdapter(e -> updateBuildRadioEnablement());
 
-            globalBuildButton.addSelectionListener(buildRadioSelected);
-            projectBuildButton.addSelectionListener(buildRadioSelected);
-        }
-        return area;
-    }
+			globalBuildButton.addSelectionListener(buildRadioSelected);
+			projectBuildButton.addSelectionListener(buildRadioSelected);
+		}
+		return area;
+	}
 
 	private static boolean useNativeSearchField(Composite composite) {
 		boolean useNativeSearchField = true;
@@ -386,12 +386,12 @@ public class CleanDialog extends MessageDialog {
 		}
 	}
 
-    @Override
+	@Override
 	protected Control createContents(Composite parent) {
-    	Control contents= super.createContents(parent);
-    	updateEnablement();
-    	return contents;
-    }
+		Control contents= super.createContents(parent);
+		updateEnablement();
+		return contents;
+	}
 
 	private void checkAllItemsIfSelectAllEventIsFired(SelectionEvent e) {
 		if (e.item == null) {
@@ -403,188 +403,188 @@ public class CleanDialog extends MessageDialog {
 	private void createProjectSelectionTable(Composite parent) {
 		projectNames = CheckboxTableViewer.newCheckList(parent, SWT.BORDER);
 		projectNames.getTable().addSelectionListener(SelectionListener.widgetSelectedAdapter(this::checkAllItemsIfSelectAllEventIsFired));
-        projectNames.setContentProvider(new WorkbenchContentProvider());
-        projectNames.setLabelProvider(new WorkbenchLabelProvider());
-        projectNames.setComparator(new ResourceComparator(ResourceComparator.NAME));
-        projectNames.addFilter(new ViewerFilter() {
-            private final IProject[] projectHolder = new IProject[1];
-            @Override
+		projectNames.setContentProvider(new WorkbenchContentProvider());
+		projectNames.setLabelProvider(new WorkbenchLabelProvider());
+		projectNames.setComparator(new ResourceComparator(ResourceComparator.NAME));
+		projectNames.addFilter(new ViewerFilter() {
+			private final IProject[] projectHolder = new IProject[1];
+			@Override
 			public boolean select(Viewer viewer, Object parentElement, Object element) {
-                if (!(element instanceof IProject)) {
-                    return false;
-                }
-                IProject project = (IProject) element;
+				if (!(element instanceof IProject)) {
+					return false;
+				}
+				IProject project = (IProject) element;
 				boolean isProjectNameMatchingPattern = searchPattern.matches(project.getName());
 				if (!project.isAccessible() || !isProjectNameMatchingPattern) {
 					if (!filterText.getText().equals(IDEWorkbenchMessages.CleanDialog_typeFilterText)) {
 						return false;
 					}
-                }
-                projectHolder[0] = project;
-                return BuildUtilities.isEnabled(projectHolder, IncrementalProjectBuilder.CLEAN_BUILD);
-            }
-        });
-        projectNames.setInput(ResourcesPlugin.getWorkspace().getRoot());
+				}
+				projectHolder[0] = project;
+				return BuildUtilities.isEnabled(projectHolder, IncrementalProjectBuilder.CLEAN_BUILD);
+			}
+		});
+		projectNames.setInput(ResourcesPlugin.getWorkspace().getRoot());
 		GridData data = new GridData(SWT.FILL, SWT.FILL, true, true);
-        data.heightHint = IDialogConstants.ENTRY_FIELD_WIDTH;
-        projectNames.getTable().setLayoutData(data);
-        projectNames.setCheckedElements(selection);
-        Object[] checked = projectNames.getCheckedElements();
+		data.heightHint = IDialogConstants.ENTRY_FIELD_WIDTH;
+		projectNames.getTable().setLayoutData(data);
+		projectNames.setCheckedElements(selection);
+		Object[] checked = projectNames.getCheckedElements();
 		// reveal first checked project
 		if (checked.length > 0) {
-            projectNames.reveal(checked[0]);
-        }
+			projectNames.reveal(checked[0]);
+		}
 		projectNames.addCheckStateListener(event -> checkStateChanged());
-    }
+	}
 
 	private void checkStateChanged() {
 		selection = projectNames.getCheckedElements();
 		updateEnablement();
 	}
 
-    /**
-     * Performs the actual clean operation.
-     * @param cleanAll if <code>true</true> clean all projects
-     * @param monitor The monitor that the build will report to
-     * @throws CoreException thrown if there is a problem from the
-     * core builder.
-     */
-    protected void doClean(boolean cleanAll, IProgressMonitor monitor)
-            throws CoreException {
-        if (cleanAll) {
+	/**
+	 * Performs the actual clean operation.
+	 * @param cleanAll if <code>true</true> clean all projects
+	 * @param monitor The monitor that the build will report to
+	 * @throws CoreException thrown if there is a problem from the
+	 * core builder.
+	 */
+	protected void doClean(boolean cleanAll, IProgressMonitor monitor)
+			throws CoreException {
+		if (cleanAll) {
 			ResourcesPlugin.getWorkspace().build(IncrementalProjectBuilder.CLEAN_BUILD, monitor);
-        } else {
+		} else {
 			SubMonitor subMonitor = SubMonitor.convert(monitor, IDEWorkbenchMessages.CleanDialog_cleanSelectedTaskName,
 					selection.length);
 			for (Object currentSelection : selection) {
 				((IProject) currentSelection).build(IncrementalProjectBuilder.CLEAN_BUILD, subMonitor.split(1));
-            }
-        }
-    }
+			}
+		}
+	}
 
-    /**
+	/**
 	 * Updates the enablement of the dialog elements based on the current
 	 * choices in the dialog.
 	 */
-    protected void updateEnablement() {
+	protected void updateEnablement() {
 		projectNames.getTable().setEnabled(!alwaysCleanButton.getSelection());
 		filterText.setEnabled(!alwaysCleanButton.getSelection());
 
 		boolean enabled = selection.length > 0 || alwaysCleanButton.getSelection();
-        getButton(OK).setEnabled(enabled);
-        if (globalBuildButton != null) {
-            globalBuildButton.setEnabled(buildNowButton.getSelection());
-        }
-        if (projectBuildButton != null) {
-            projectBuildButton.setEnabled(buildNowButton.getSelection());
-        }
-    }
+		getButton(OK).setEnabled(enabled);
+		if (globalBuildButton != null) {
+			globalBuildButton.setEnabled(buildNowButton.getSelection());
+		}
+		if (projectBuildButton != null) {
+			projectBuildButton.setEnabled(buildNowButton.getSelection());
+		}
+	}
 
-    /**
-     * Updates the enablement of the dialog's build selection radio
-     * buttons.
-     */
-    protected void updateBuildRadioEnablement() {
-        projectBuildButton.setSelection(!globalBuildButton.getSelection());
-    }
+	/**
+	 * Updates the enablement of the dialog's build selection radio
+	 * buttons.
+	 */
+	protected void updateBuildRadioEnablement() {
+		projectBuildButton.setSelection(!globalBuildButton.getSelection());
+	}
 
-    @Override
+	@Override
 	public boolean close() {
-        persistDialogSettings(getShell(), DIALOG_SETTINGS_SECTION);
-        return super.close();
-    }
+		persistDialogSettings(getShell(), DIALOG_SETTINGS_SECTION);
+		return super.close();
+	}
 
-    @Override
+	@Override
 	protected Point getInitialLocation(Point initialSize) {
-        Point p = getInitialLocation(DIALOG_SETTINGS_SECTION);
-        return p != null ? p : super.getInitialLocation(initialSize);
-    }
+		Point p = getInitialLocation(DIALOG_SETTINGS_SECTION);
+		return p != null ? p : super.getInitialLocation(initialSize);
+	}
 
-    @Override
+	@Override
 	protected Point getInitialSize() {
-        Point p = super.getInitialSize();
-        return getInitialSize(DIALOG_SETTINGS_SECTION, p);
-    }
+		Point p = super.getInitialSize();
+		return getInitialSize(DIALOG_SETTINGS_SECTION, p);
+	}
 
-    /**
-     * Returns the initial location which is persisted in the IDE Plugin dialog settings
-     * under the provided dialog setttings section name.
-     * If location is not persisted in the settings, the <code>null</code> is returned.
-     *
-     * @param dialogSettingsSectionName The name of the dialog settings section
-     * @return The initial location or <code>null</code>
-     */
-    public Point getInitialLocation(String dialogSettingsSectionName) {
-        IDialogSettings settings = getDialogSettings(dialogSettingsSectionName);
-        try {
-            int x= settings.getInt(DIALOG_ORIGIN_X);
-            int y= settings.getInt(DIALOG_ORIGIN_Y);
-            return new Point(x,y);
-        } catch (NumberFormatException e) {
-        }
-        return null;
-    }
+	/**
+	 * Returns the initial location which is persisted in the IDE Plugin dialog settings
+	 * under the provided dialog setttings section name.
+	 * If location is not persisted in the settings, the <code>null</code> is returned.
+	 *
+	 * @param dialogSettingsSectionName The name of the dialog settings section
+	 * @return The initial location or <code>null</code>
+	 */
+	public Point getInitialLocation(String dialogSettingsSectionName) {
+		IDialogSettings settings = getDialogSettings(dialogSettingsSectionName);
+		try {
+			int x= settings.getInt(DIALOG_ORIGIN_X);
+			int y= settings.getInt(DIALOG_ORIGIN_Y);
+			return new Point(x,y);
+		} catch (NumberFormatException e) {
+		}
+		return null;
+	}
 
-    private IDialogSettings getDialogSettings(String dialogSettingsSectionName) {
-        IDialogSettings settings = IDEWorkbenchPlugin.getDefault().getDialogSettings();
-        IDialogSettings section = settings.getSection(dialogSettingsSectionName);
-        if (section == null) {
-            section = settings.addNewSection(dialogSettingsSectionName);
-        }
-        return section;
-    }
+	private IDialogSettings getDialogSettings(String dialogSettingsSectionName) {
+		IDialogSettings settings = IDEWorkbenchPlugin.getDefault().getDialogSettings();
+		IDialogSettings section = settings.getSection(dialogSettingsSectionName);
+		if (section == null) {
+			section = settings.addNewSection(dialogSettingsSectionName);
+		}
+		return section;
+	}
 
-    /**
-     * Persists the location and dimensions of the shell and other user settings in the
-     * plugin's dialog settings under the provided dialog settings section name
-     *
-     * @param shell The shell whose geometry is to be stored
-     * @param dialogSettingsSectionName The name of the dialog settings section
-     */
-    private void persistDialogSettings(Shell shell, String dialogSettingsSectionName) {
-        Point shellLocation = shell.getLocation();
-        Point shellSize = shell.getSize();
-        IDialogSettings settings = getDialogSettings(dialogSettingsSectionName);
-        settings.put(DIALOG_ORIGIN_X, shellLocation.x);
-        settings.put(DIALOG_ORIGIN_Y, shellLocation.y);
-        settings.put(DIALOG_WIDTH, shellSize.x);
-        settings.put(DIALOG_HEIGHT, shellSize.y);
+	/**
+	 * Persists the location and dimensions of the shell and other user settings in the
+	 * plugin's dialog settings under the provided dialog settings section name
+	 *
+	 * @param shell The shell whose geometry is to be stored
+	 * @param dialogSettingsSectionName The name of the dialog settings section
+	 */
+	private void persistDialogSettings(Shell shell, String dialogSettingsSectionName) {
+		Point shellLocation = shell.getLocation();
+		Point shellSize = shell.getSize();
+		IDialogSettings settings = getDialogSettings(dialogSettingsSectionName);
+		settings.put(DIALOG_ORIGIN_X, shellLocation.x);
+		settings.put(DIALOG_ORIGIN_Y, shellLocation.y);
+		settings.put(DIALOG_WIDTH, shellSize.x);
+		settings.put(DIALOG_HEIGHT, shellSize.y);
 
-        if (buildNowButton != null) {
-            settings.put(BUILD_NOW, buildNowButton.getSelection());
-        }
-        if (globalBuildButton != null) {
-            settings.put(BUILD_ALL, globalBuildButton.getSelection());
-        }
+		if (buildNowButton != null) {
+			settings.put(BUILD_NOW, buildNowButton.getSelection());
+		}
+		if (globalBuildButton != null) {
+			settings.put(BUILD_ALL, globalBuildButton.getSelection());
+		}
 
 		settings.put(TOGGLE_SELECTED, !alwaysCleanButton.getSelection());
-    }
+	}
 
-    /**
-     * Returns the initial size which is the larger of the <code>initialSize</code> or
-     * the size persisted in the IDE UI Plugin dialog settings under the provided dialog setttings section name.
-     * If no size is persisted in the settings, the <code>initialSize</code> is returned.
-     *
-     * @param initialSize The initialSize to compare against
-     * @param dialogSettingsSectionName The name of the dialog settings section
-     * @return the initial size
-     */
-    private Point getInitialSize(String dialogSettingsSectionName, Point initialSize) {
-        IDialogSettings settings = getDialogSettings(dialogSettingsSectionName);
-        try {
-            int x, y;
-            x = settings.getInt(DIALOG_WIDTH);
-            y = settings.getInt(DIALOG_HEIGHT);
-            return new Point(Math.max(x, initialSize.x), Math.max(y, initialSize.y));
-        } catch (NumberFormatException e) {
-        }
-        return initialSize;
-    }
+	/**
+	 * Returns the initial size which is the larger of the <code>initialSize</code> or
+	 * the size persisted in the IDE UI Plugin dialog settings under the provided dialog setttings section name.
+	 * If no size is persisted in the settings, the <code>initialSize</code> is returned.
+	 *
+	 * @param initialSize The initialSize to compare against
+	 * @param dialogSettingsSectionName The name of the dialog settings section
+	 * @return the initial size
+	 */
+	private Point getInitialSize(String dialogSettingsSectionName, Point initialSize) {
+		IDialogSettings settings = getDialogSettings(dialogSettingsSectionName);
+		try {
+			int x, y;
+			x = settings.getInt(DIALOG_WIDTH);
+			y = settings.getInt(DIALOG_HEIGHT);
+			return new Point(Math.max(x, initialSize.x), Math.max(y, initialSize.y));
+		} catch (NumberFormatException e) {
+		}
+		return initialSize;
+	}
 
-    @Override
+	@Override
 	protected boolean isResizable() {
-        return true;
-    }
+		return true;
+	}
 
 	/**
 	 * Create the button that clears the text.
