@@ -12,6 +12,7 @@
  *     IBM Corporation - initial API and implementation
  *     Broadcom Corp. - James Blackburn -  Fix for Bug 305529 -
  *     					[Markers] NPE in MarkerFieldEditor if MarkerFieldConfiguration scope is unset
+ *     Kit Lo (IBM) - Bug 542713 - Empty entries in Show menu after switching UI language to German
  *******************************************************************************/
 
 package org.eclipse.ui.internal.views.markers;
@@ -32,7 +33,6 @@ import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IAdaptable;
 import org.eclipse.core.runtime.IConfigurationElement;
 import org.eclipse.core.runtime.IPath;
-import org.eclipse.core.runtime.IStatus;
 import org.eclipse.ui.IMemento;
 import org.eclipse.ui.IWorkbenchPage;
 import org.eclipse.ui.IWorkbenchPreferenceConstants;
@@ -222,7 +222,7 @@ class MarkerFieldFilterGroup {
 			if (element == null) {
 				id = USER + String.valueOf(System.currentTimeMillis());
 			} else {
-				id = element.getAttribute(MarkerSupportInternalUtilities.ATTRIBUTE_NAME);
+				id = element.getAttribute(MarkerSupportInternalUtilities.ATTRIBUTE_ID);
 			}
 		}
 		return id;
@@ -401,7 +401,7 @@ class MarkerFieldFilterGroup {
 
 		String enabledString = memento.getString(TAG_ENABLED);
 		if (enabledString != null && enabledString.length() > 0) {
-			enabled = Boolean.valueOf(enabledString).booleanValue();
+			enabled = Boolean.parseBoolean(enabledString);
 		}
 
 		Integer resourceSetting = memento.getInteger(MarkerFilter.TAG_ON_RESOURCE);
@@ -443,7 +443,7 @@ class MarkerFieldFilterGroup {
 	void loadSettings(IMemento memento) {
 		String stringValue = memento.getString(TAG_ENABLED);
 		if (stringValue != null && stringValue.length() > 0){
-			enabled = Boolean.valueOf(stringValue).booleanValue();
+			enabled = Boolean.parseBoolean(stringValue);
 		}
 		scope = memento.getInteger(TAG_SCOPE).intValue();
 
@@ -519,8 +519,7 @@ class MarkerFieldFilterGroup {
 			} catch (InstantiationException | IllegalArgumentException | IllegalAccessException
 					| InvocationTargetException | NoSuchMethodException
 					| SecurityException e) {
-				StatusManager.getManager().handle(StatusUtil.newStatus(IStatus.ERROR, e.getLocalizedMessage(), e),
-						StatusManager.SHOW);
+				StatusManager.getManager().handle(StatusUtil.newError(e), StatusManager.SHOW);
 				return false;
 			}
 		}
