@@ -481,9 +481,10 @@ public class SmartImportRootWizardPage extends WizardPage {
 		Link showDetectorsLink = new Link(parent, SWT.NONE);
 		showDetectorsLink.setText(DataTransferMessages.SmartImportWizardPage_showAvailableDetectors);
 		GridData gridData = new GridData();
-        gridData.horizontalAlignment = GridData.FILL;
-        gridData.grabExcessHorizontalSpace = true;
-        showDetectorsLink.setLayoutData(gridData);
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		gridData.horizontalSpan = 4;
+		showDetectorsLink.setLayoutData(gridData);
 		showDetectorsLink.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
@@ -773,13 +774,10 @@ public class SmartImportRootWizardPage extends WizardPage {
 	public Set<IWorkingSet> getSelectedWorkingSets() {
 		this.workingSets = new HashSet<>();
 		// workingSetsGroup doesn't support listeners...
-		Runnable workingSetsRetriever = new Runnable() {
-			@Override
-			public void run() {
-				for (IWorkingSet workingSet : SmartImportRootWizardPage.this.workingSetsGroup
-						.getSelectedWorkingSets()) {
-					SmartImportRootWizardPage.this.workingSets.add(workingSet);
-				}
+		Runnable workingSetsRetriever = () -> {
+			for (IWorkingSet workingSet : SmartImportRootWizardPage.this.workingSetsGroup
+					.getSelectedWorkingSets()) {
+				SmartImportRootWizardPage.this.workingSets.add(workingSet);
 			}
 		};
 		if (Display.getCurrent() == null) {
