@@ -322,8 +322,8 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 	}
 
 	// dialog store id constants
-    private static final String STORE_DIRECTORIES = "WizardProjectsImportPage.STORE_DIRECTORIES";//$NON-NLS-1$
-    private static final String STORE_ARCHIVES = "WizardProjectsImportPage.STORE_ARCHIVES";//$NON-NLS-1$
+	private static final String STORE_DIRECTORIES = "WizardProjectsImportPage.STORE_DIRECTORIES";//$NON-NLS-1$
+	private static final String STORE_ARCHIVES = "WizardProjectsImportPage.STORE_ARCHIVES";//$NON-NLS-1$
 
 	private static final String STORE_NESTED_PROJECTS = "WizardProjectsImportPage.STORE_NESTED_PROJECTS"; //$NON-NLS-1$
 
@@ -410,7 +410,7 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 	 */
 	public WizardProjectsImportPage(String pageName,String initialPath,
 			IStructuredSelection currentSelection) {
- 		super(pageName);
+		super(pageName);
 		if (initialPath != null) {
 			this.initialPath = initialPath;
 		} else {
@@ -1059,9 +1059,7 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 			try {
 				directoriesVisited.add(directory.getCanonicalPath());
 			} catch (IOException exception) {
-				StatusManager.getManager().handle(
-						StatusUtil.newStatus(IStatus.ERROR, exception
-								.getLocalizedMessage(), exception));
+				StatusManager.getManager().handle(StatusUtil.newError(exception));
 			}
 		}
 
@@ -1091,9 +1089,7 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 						continue;
 					}
 				} catch (IOException exception) {
-					StatusManager.getManager().handle(
-							StatusUtil.newStatus(IStatus.ERROR, exception
-									.getLocalizedMessage(), exception));
+					StatusManager.getManager().handle(StatusUtil.newError(exception));
 
 				}
 				collectProjectFilesFromDirectory(files, dir,
@@ -1270,7 +1266,7 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 
 		IWorkingSet[] selectedWorkingSets = workingSetGroup.getSelectedWorkingSets();
 		if(selectedWorkingSets == null || selectedWorkingSets.length == 0)
-		 {
+		{
 			return; // no Working set is selected
 		}
 		IWorkingSetManager workingSetManager = PlatformUI.getWorkbench().getWorkingSetManager();
@@ -1457,11 +1453,11 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 	 */
 	public ProjectRecord[] getProjectRecords() {
 		List<ProjectRecord> projectRecords = new ArrayList<>();
-		for (int i = 0; i < selectedProjects.length; i++) {
-			String projectName = selectedProjects[i].getProjectName();
-			selectedProjects[i].hasConflicts = (isProjectInWorkspacePath(projectName) && copyFiles)
+		for (ProjectRecord selectedProject : selectedProjects) {
+			String projectName = selectedProject.getProjectName();
+			selectedProject.hasConflicts = (isProjectInWorkspacePath(projectName) && copyFiles)
 					|| isProjectInWorkspace(projectName);
-			projectRecords.add(selectedProjects[i]);
+			projectRecords.add(selectedProject);
 		}
 		return projectRecords
 				.toArray(new ProjectRecord[projectRecords.size()]);
@@ -1515,10 +1511,10 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 		// take care of the checkbox
 		IDialogSettings settings = getDialogSettings();
 		if (settings != null) {
-            restoreFromHistory(settings, STORE_DIRECTORIES, directoryPathField);
-            restoreFromHistory(settings, STORE_ARCHIVES, archivePathField);
+			restoreFromHistory(settings, STORE_DIRECTORIES, directoryPathField);
+			restoreFromHistory(settings, STORE_ARCHIVES, archivePathField);
 
-            // checkbox
+			// checkbox
 			nestedProjects = settings.getBoolean(STORE_NESTED_PROJECTS);
 			nestedProjectsCheckbox.setSelection(nestedProjects);
 
@@ -1587,10 +1583,10 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 	public void saveWidgetValues() {
 		IDialogSettings settings = getDialogSettings();
 		if (settings != null) {
-            saveInHistory(settings, STORE_DIRECTORIES, directoryPathField.getText());
-            saveInHistory(settings, STORE_ARCHIVES, archivePathField.getText());
+			saveInHistory(settings, STORE_DIRECTORIES, directoryPathField.getText());
+			saveInHistory(settings, STORE_ARCHIVES, archivePathField.getText());
 
-            settings.put(STORE_NESTED_PROJECTS, nestedProjectsCheckbox.getSelection());
+			settings.put(STORE_NESTED_PROJECTS, nestedProjectsCheckbox.getSelection());
 
 			settings.put(STORE_COPY_PROJECT_ID, copyCheckbox.getSelection());
 
