@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2003, 2017 IBM Corporation and others.
+ * Copyright (c) 2003, 2017, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -12,6 +12,7 @@
  *     IBM Corporation - initial API and implementation
  *     anton.leherbauer@windriver.com - bug 220599 make CommonNavigator a ShowInSource
  *     rob.stryker@jboss.com - bug 250198 Slight changes for easier subclassing
+ *     Stefan Winkler <stefan@winklerweb.net> - bug 178019 - CNF Tooltip support
  *******************************************************************************/
 package org.eclipse.ui.navigator;
 
@@ -19,6 +20,7 @@ import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.PerformanceStats;
 import org.eclipse.core.runtime.SafeRunner;
 import org.eclipse.jface.action.IAction;
+import org.eclipse.jface.viewers.ColumnViewerToolTipSupport;
 import org.eclipse.jface.viewers.DoubleClickEvent;
 import org.eclipse.jface.viewers.IDoubleClickListener;
 import org.eclipse.jface.viewers.ILabelProvider;
@@ -86,11 +88,10 @@ import org.eclipse.ui.part.ViewPart;
  * Clients that wish to define their own custom extensible navigator view using
  * CommonNavigator need to specify an instance of the
  * <b>org.eclipse.ui.views</b> extension point:
+ * </p>
  *
  * <pre>
- *
- *          &lt;extension
- *          		point=&quot;org.eclipse.ui.views&quot;&gt;
+ *          &lt;extension point=&quot;org.eclipse.ui.views&quot;&gt;
  *          	&lt;view
  *          		name=&quot;My Custom View&quot;
  *          		icon=&quot;relative/path/to/icon.gif&quot;
@@ -99,10 +100,8 @@ import org.eclipse.ui.part.ViewPart;
  *          		id=&quot;org.acme.MyCustomNavigatorID&quot;&gt;
  *          	&lt;/view&gt;
  *          &lt;/extension&gt;
- *
  * </pre>
  *
- * </p>
  *
  * <p>
  * CommonNavigator gets its initial input (during initialization) from the
@@ -193,7 +192,7 @@ public class CommonNavigator extends ViewPart implements ISetSelectionTarget, IS
 		try {
 			commonViewer.getControl().setRedraw(false);
 
-	        INavigatorFilterService filterService = commonViewer
+			INavigatorFilterService filterService = commonViewer
 					.getNavigatorContentService().getFilterService();
 			ViewerFilter[] visibleFilters = filterService.getVisibleFilters(true);
 			for (ViewerFilter visibleFilter : visibleFilters) {
@@ -215,9 +214,9 @@ public class CommonNavigator extends ViewPart implements ISetSelectionTarget, IS
 			commonViewer.getControl().setRedraw(true);
 		}
 
-        commonViewer.createFrameList();
+		commonViewer.createFrameList();
 
-        /*
+		/*
 		 * Create the CommonNavigatorManager last because information about the
 		 * state of the CommonNavigator is required for the initialization of
 		 * the CommonNavigatorManager
@@ -261,6 +260,12 @@ public class CommonNavigator extends ViewPart implements ISetSelectionTarget, IS
 			helpContext = HELP_CONTEXT;
 		PlatformUI.getWorkbench().getHelpSystem().setHelp(commonViewer.getControl(), helpContext);
 
+		boolean enableToolTipSupport = commonViewer.getNavigatorContentService().getViewerDescriptor()
+				.getBooleanConfigProperty(INavigatorViewerDescriptor.PROP_ENABLE_TOOLTIP_SUPPORT);
+		if (enableToolTipSupport) {
+			ColumnViewerToolTipSupport.enableFor(commonViewer);
+		}
+
 		stats.endRun();
 	}
 
@@ -459,21 +464,21 @@ public class CommonNavigator extends ViewPart implements ISetSelectionTarget, IS
 			return adapter.cast(this);
 		} else if (adapter == IShowInSource.class) {
 			return adapter.cast(getShowInSource());
-        }
+		}
 		return super.getAdapter(adapter);
 	}
 
-    /**
-     * Returns the <code>IShowInSource</code> for this view.
-     */
-    private IShowInSource getShowInSource() {
-        return new IShowInSource() {
-            @Override
+	/**
+	 * Returns the <code>IShowInSource</code> for this view.
+	 */
+	private IShowInSource getShowInSource() {
+		return new IShowInSource() {
+			@Override
 			public ShowInContext getShowInContext() {
-                return new ShowInContext(getCommonViewer().getInput(), getCommonViewer().getSelection());
-            }
-        };
-    }
+				return new ShowInContext(getCommonViewer().getInput(), getCommonViewer().getSelection());
+			}
+		};
+	}
 
 	/**
 	 * @return The Navigator Action Service which populates this instance of Common
