@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -20,6 +20,10 @@ package org.eclipse.ui.views.properties;
 
 import java.util.HashSet;
 
+import org.eclipse.osgi.util.NLS;
+
+import org.eclipse.swt.widgets.Composite;
+
 import org.eclipse.core.runtime.Adapters;
 import org.eclipse.core.runtime.IAdaptable;
 import org.eclipse.core.runtime.IConfigurationElement;
@@ -28,6 +32,7 @@ import org.eclipse.core.runtime.IExtensionPoint;
 import org.eclipse.core.runtime.IExtensionRegistry;
 import org.eclipse.core.runtime.IRegistryEventListener;
 import org.eclipse.core.runtime.RegistryFactory;
+
 import org.eclipse.jface.action.IAction;
 import org.eclipse.jface.action.IMenuManager;
 import org.eclipse.jface.action.IToolBarManager;
@@ -35,8 +40,7 @@ import org.eclipse.jface.action.Separator;
 import org.eclipse.jface.util.IPropertyChangeListener;
 import org.eclipse.jface.util.PropertyChangeEvent;
 import org.eclipse.jface.viewers.ISelection;
-import org.eclipse.osgi.util.NLS;
-import org.eclipse.swt.widgets.Composite;
+
 import org.eclipse.ui.IEditorPart;
 import org.eclipse.ui.IMemento;
 import org.eclipse.ui.ISaveablePart;
@@ -72,10 +76,11 @@ import org.eclipse.ui.part.ShowInContext;
  * This standard view has id <code>"org.eclipse.ui.views.PropertySheet"</code>.
  * </p>
  * <p>
- * Note that property <it>sheets</it> and property sheet pages are not the
- * same thing as property <it>dialogs</it> and their property pages (the property
- * pages extension point is for contributing property pages to property dialogs).
- * Within the property sheet view, all pages are <code>IPropertySheetPage</code>s.
+ * Note that property <i>sheets</i> and property sheet pages are not the same
+ * thing as property <i>dialogs</i> and their property pages (the property pages
+ * extension point is for contributing property pages to property dialogs).
+ * Within the property sheet view, all pages are
+ * <code>IPropertySheetPage</code>s.
  * </p>
  * <p>
  * Property sheet pages are discovered by the property sheet view automatically
@@ -92,9 +97,9 @@ import org.eclipse.ui.part.ShowInContext;
  * sheet page of their own.
  * </p>
  * <p>
- * The workbench will automatically instantiate this class when a Property
- * Sheet view is needed for a workbench window. This class is not intended
- * to be instantiated or subclassed by clients.
+ * The workbench will automatically instantiate this class when a Property Sheet
+ * view is needed for a workbench window. This class is not intended to be
+ * instantiated or subclassed by clients.
  * </p>
  *
  * @see IPropertySheetPage
@@ -104,29 +109,29 @@ import org.eclipse.ui.part.ShowInContext;
  */
 public class PropertySheet extends PageBookView
 		implements ISelectionListener, IShowInTarget, IShowInSource, IRegistryEventListener, ISecondarySaveableSource {
-    /**
-     * No longer used but preserved to avoid api change
-     */
-    public static final String HELP_CONTEXT_PROPERTY_SHEET_VIEW = IPropertiesHelpContextIds.PROPERTY_SHEET_VIEW;
+	/**
+	 * No longer used but preserved to avoid api change
+	 */
+	public static final String HELP_CONTEXT_PROPERTY_SHEET_VIEW = IPropertiesHelpContextIds.PROPERTY_SHEET_VIEW;
 
-    /**
-     * Extension point used to modify behavior of the view
-     */
-    private static final String EXT_POINT = "org.eclipse.ui.propertiesView"; //$NON-NLS-1$
+	/**
+	 * Extension point used to modify behavior of the view
+	 */
+	private static final String EXT_POINT = "org.eclipse.ui.propertiesView"; //$NON-NLS-1$
 
-    /**
-     * The initial selection when the property sheet opens
-     */
-    private ISelection bootstrapSelection;
+	/**
+	 * The initial selection when the property sheet opens
+	 */
+	private ISelection bootstrapSelection;
 
-    /**
-     * The current selection of the property sheet
-     */
-    private ISelection currentSelection;
+	/**
+	 * The current selection of the property sheet
+	 */
+	private ISelection currentSelection;
 
-    /**
-     * The current part for which this property sheets is active
-     */
+	/**
+	 * The current part for which this property sheets is active
+	 */
 	private IWorkbenchPart currentPart;
 
 	/**
@@ -150,6 +155,9 @@ public class PropertySheet extends PageBookView
 
 	private final SaveablesTracker saveablesTracker;
 
+	private boolean needsUpdate = false;
+
+
 	/**
 	 * Propagates state changes of the saveable part tracked by this properties
 	 * view, to properly update the dirty status. See bug 495567 comment 18.
@@ -191,40 +199,43 @@ public class PropertySheet extends PageBookView
 
 	}
 
-    /**
-     * Creates a property sheet view.
-     */
-    public PropertySheet() {
-        super();
-        pinPropertySheetAction = new PinPropertySheetAction();
-        RegistryFactory.getRegistry().addListener(this, EXT_POINT);
+	/**
+	 * Creates a property sheet view.
+	 */
+	public PropertySheet() {
+		super();
+		pinPropertySheetAction = new PinPropertySheetAction();
+		RegistryFactory.getRegistry().addListener(this, EXT_POINT);
 		saveablesTracker = new SaveablesTracker();
-    }
+	}
 
-    @Override
+	@Override
 	protected IPage createDefaultPage(PageBook book) {
 		IPageBookViewPage page = (IPageBookViewPage) Adapters.adapt(this, IPropertySheetPage.class);
-        if(page == null) {
-        	page = new PropertySheetPage();
-        }
-        initPage(page);
-        page.createControl(book);
-        return page;
-    }
+		if(page == null) {
+			page = new PropertySheetPage();
+		}
+		initPage(page);
+		page.createControl(book);
+		return page;
+	}
 
 	/**
-     * The <code>PropertySheet</code> implementation of this <code>IWorkbenchPart</code>
-     * method creates a <code>PageBook</code> control with its default page showing.
-     */
-    @Override
+	 * The <code>PropertySheet</code> implementation of this <code>IWorkbenchPart</code>
+	 * method creates a <code>PageBook</code> control with its default page showing.
+	 */
+	@Override
 	public void createPartControl(Composite parent) {
-        super.createPartControl(parent);
+		super.createPartControl(parent);
 
-        pinPropertySheetAction.addPropertyChangeListener(new IPropertyChangeListener(){
+		pinPropertySheetAction.addPropertyChangeListener(new IPropertyChangeListener(){
 			@Override
 			public void propertyChange(PropertyChangeEvent event) {
 				if (IAction.CHECKED.equals(event.getProperty())) {
 					updateContentDescription();
+					if (!isPinned()) {
+						selectionChanged(currentPart, currentSelection);
+					}
 				}
 			}
 		});
@@ -241,58 +252,58 @@ public class PropertySheet extends PageBookView
 		if (saveables instanceof SaveablesList) {
 			((SaveablesList) saveables).addModelLifecycleListener(saveablesTracker);
 		}
-        getSite().getPage().getWorkbenchWindow().getWorkbench().getHelpSystem()
+		getSite().getPage().getWorkbenchWindow().getWorkbench().getHelpSystem()
 				.setHelp(getPageBook(),
 						IPropertiesHelpContextIds.PROPERTY_SHEET_VIEW);
-    }
+	}
 
-    @Override
+	@Override
 	public void dispose() {
 		IWorkbenchPartSite site = getSite();
 		IWorkbenchPage page = site.getPage();
 		ISaveablesLifecycleListener saveables = site.getService(ISaveablesLifecycleListener.class);
 
-        // remove ourselves as a selection and registry listener
+		// remove ourselves as a selection and registry listener
 		page.removePostSelectionListener(this);
-        RegistryFactory.getRegistry().removeListener(this);
+		RegistryFactory.getRegistry().removeListener(this);
 		if (saveables instanceof SaveablesList) {
 			((SaveablesList) saveables).removeModelLifecycleListener(saveablesTracker);
 		}
-        currentPart = null;
-        currentSelection = null;
-        pinPropertySheetAction = null;
-        super.dispose();
-    }
+		currentPart = null;
+		currentSelection = null;
+		pinPropertySheetAction = null;
+		super.dispose();
+	}
 
-    @Override
+	@Override
 	protected PageRec doCreatePage(IWorkbenchPart part) {
-        // Get a custom property sheet page but not if the part is also a
+		// Get a custom property sheet page but not if the part is also a
 		// PropertySheet. In this case the child property sheet would
 		// accidentally reuse the parent's property sheet page.
-    	if(part instanceof PropertySheet) {
-    		return null;
-    	}
+		if(part instanceof PropertySheet) {
+			return null;
+		}
 		IPropertySheetPage page = Adapters.adapt(part, IPropertySheetPage.class);
-        if (page != null) {
-            if (page instanceof IPageBookViewPage) {
+		if (page != null) {
+			if (page instanceof IPageBookViewPage) {
 				initPage((IPageBookViewPage) page);
 			}
-            page.createControl(getPageBook());
-            return new PageRec(part, page);
-        }
+			page.createControl(getPageBook());
+			return new PageRec(part, page);
+		}
 
-        // Use the default page
-        return null;
-    }
+		// Use the default page
+		return null;
+	}
 
-    @Override
+	@Override
 	protected void doDestroyPage(IWorkbenchPart part, PageRec rec) {
-        IPropertySheetPage page = (IPropertySheetPage) rec.page;
-        page.dispose();
-        rec.dispose();
-    }
+		IPropertySheetPage page = (IPropertySheetPage) rec.page;
+		page.dispose();
+		rec.dispose();
+	}
 
-    @Override
+	@Override
 	protected IWorkbenchPart getBootstrapPart() {
 		IWorkbenchPage page = getSite().getPage();
 		if (page == null) {
@@ -334,39 +345,42 @@ public class PropertySheet extends PageBookView
 			}
 		}
 		return null;
-    }
+	}
 
-    @Override
+	@Override
 	public void init(IViewSite site) throws PartInitException {
-   		site.getPage().addPostSelectionListener(this);
-   		super.init(site);
-    }
+			site.getPage().addPostSelectionListener(this);
+			super.init(site);
+	}
 
 	@Override
 	public void saveState(IMemento memento) {
-		// close all but the primary/parent property sheet
-		String secondaryId = getViewSite().getSecondaryId();
+		// close all but the primary/parent property sheet on shutdown
+		IViewSite viewSite = getViewSite();
+		String secondaryId = viewSite.getSecondaryId();
 		if (null == secondaryId) {
 			super.saveState(memento);
 		} else {
-			getViewSite().getPage().hideView(this);
+			if (viewSite.getWorkbenchWindow().isClosing()) {
+				viewSite.getPage().hideView(this);
+			}
 		}
 	}
 
-    @Override
+	@Override
 	protected boolean isImportant(IWorkbenchPart part) {
 		// Don't interfere with other property views
 		if (part == null) {
 			return false;
 		}
-    	IWorkbenchPartSite site = part.getSite();
+		IWorkbenchPartSite site = part.getSite();
 		if (site == null) {
 			return false;
 		}
 		String partID = site.getId();
 		boolean isPropertyView = getSite().getId().equals(partID);
 		return !isPinned() && !isPropertyView && !isViewIgnored(partID);
-    }
+	}
 
 	@Override
 	public void partClosed(IWorkbenchPart part) {
@@ -381,7 +395,7 @@ public class PropertySheet extends PageBookView
 
 	@Override
 	protected void partVisible(IWorkbenchPart part) {
-	    super.partVisible(part);
+		super.partVisible(part);
 		if (wasHidden && part == this) {
 			if (selectionUpdatePending) {
 				showSelectionAndDescription();
@@ -389,22 +403,22 @@ public class PropertySheet extends PageBookView
 		}
 	}
 
-    @Override
+	@Override
 	protected void partHidden(IWorkbenchPart part) {
 		if (part == this) {
 			wasHidden = true;
 		}
-    	// Explicitly ignore parts becoming hidden as this
-    	// can cause issues when the Property View is maximized
-    	// See bug 325743 for more details
-    }
+		// Explicitly ignore parts becoming hidden as this
+		// can cause issues when the Property View is maximized
+		// See bug 325743 for more details
+	}
 
 	/**
-     * The <code>PropertySheet</code> implementation of this <code>IPartListener</code>
-     * method first sees if the active part is an <code>IContributedContentsView</code>
-     * adapter and if so, asks it for its contributing part.
-     */
-    @Override
+	 * The <code>PropertySheet</code> implementation of this <code>IPartListener</code>
+	 * method first sees if the active part is an <code>IContributedContentsView</code>
+	 * adapter and if so, asks it for its contributing part.
+	 */
+	@Override
 	public void partActivated(IWorkbenchPart part) {
 		if (wasHidden && part == this) {
 			wasHidden = false;
@@ -414,64 +428,73 @@ public class PropertySheet extends PageBookView
 			}
 			return;
 		}
+
+		IContributedContentsView view = Adapters.adapt(part, IContributedContentsView.class);
+		IWorkbenchPart source = null;
+		if (view != null) {
+			source = view.getContributingPart();
+		}
+		if (source == null) {
+			source = part;
+		}
+
 		if (wasHidden) {
 			IWorkbenchPartSite site = getSite();
 			IWorkbenchPage page = site.getPage();
 			IViewPart[] stack = page.getViewStack(this);
 			if (stack != null) {
 				for (IViewPart vPart : stack) {
-					if (vPart == part) {
-						// don't react on activation of parts from same stack,
-						// see bug 485154.
+					if (vPart == source) {
+						// don't react on activation of (contributing) parts from same stack,
+						// see bug 485154 and 530131.
 						return;
 					}
 				}
 			}
 		}
 
-		IContributedContentsView view = Adapters.adapt(part, IContributedContentsView.class);
-        IWorkbenchPart source = null;
-        if (view != null) {
-			source = view.getContributingPart();
-		}
-        if (source != null) {
-			super.partActivated(source);
-		} else {
-			super.partActivated(part);
+		super.partActivated(source);
+
+		if(isImportant(part)) {
+			currentPart = part;
+			// reset the selection (to allow selectionChanged() accept part change for empty selections)
+			currentSelection = null;
 		}
 
-        if(isImportant(part)) {
-        	currentPart = part;
-        	// reset the selection (to allow selectionChanged() accept part change for empty selections)
-        	currentSelection = null;
-        }
-
-        // When the view is first opened, pass the selection to the page
-        if (bootstrapSelection != null) {
-            IPropertySheetPage page = (IPropertySheetPage) getCurrentPage();
-            if (page != null) {
+		// When the view is first opened, pass the selection to the page
+		if (bootstrapSelection != null) {
+			IPropertySheetPage page = (IPropertySheetPage) getCurrentPage();
+			if (page != null) {
 				page.selectionChanged(part, bootstrapSelection);
 			}
-            bootstrapSelection = null;
-        }
-    }
+			bootstrapSelection = null;
+		}
+	}
 
-    @Override
-    public void selectionChanged(IWorkbenchPart part, ISelection sel) {
+	@Override
+	public void selectionChanged(IWorkbenchPart part, ISelection sel) {
 		// we ignore selection if we are hidden OR selection is coming from
 		// another source as the last one
 		if (part == null || !part.equals(currentPart)) {
 			return;
 		}
 
-		// we ignore null selection, or if we are pinned, or our own selection
-		// or same selection
-		if (sel == null || !isImportant(part) || sel.equals(currentSelection)) {
+		if (isPinned()) {
+			currentPart = part;
+			currentSelection = sel;
+			needsUpdate = true;
 			return;
 		}
 
-        currentPart = part;
-        currentSelection = sel;
+		// we ignore null selection, or if we are pinned, or our own selection
+		// or same selection
+		if (sel == null || !isImportant(part) || (!needsUpdate && sel.equals(currentSelection))) {
+			return;
+		}
+
+		currentPart = part;
+		currentSelection = sel;
+		needsUpdate = false;
 
 		boolean visible = getSite() != null && getSite().getPage().isPartVisible(this);
 		if (!visible) {
@@ -479,9 +502,9 @@ public class PropertySheet extends PageBookView
 			return;
 		}
 
-        // pass the selection to the page
+		// pass the selection to the page
 		showSelectionAndDescription();
-    }
+	}
 
 	private void updateContentDescription() {
 		if (isPinned() && currentPart != null) {
@@ -629,8 +652,8 @@ public class PropertySheet extends PageBookView
 	private HashSet<String> getIgnoredViews() {
 		if (ignoredViews == null) {
 			ignoredViews = new HashSet<>();
-	        IExtensionRegistry registry = RegistryFactory.getRegistry();
-	        IExtensionPoint ep = registry.getExtensionPoint(EXT_POINT);
+			IExtensionRegistry registry = RegistryFactory.getRegistry();
+			IExtensionPoint ep = registry.getExtensionPoint(EXT_POINT);
 			if (ep != null) {
 				IExtension[] extensions = ep.getExtensions();
 				for (IExtension extension : extensions) {
