@@ -18,18 +18,17 @@ import org.eclipse.swt.widgets.Menu;
 
 /**
  * Interface for a pulldown action that is contributed into the workbench window
- * tool bar.  It extends <code>IWorkbenchWindowActionDelegate</code> and adds an
+ * tool bar. It extends <code>IWorkbenchWindowActionDelegate</code> and adds an
  * initialization method to define the menu creator for the action.
  */
-public interface IWorkbenchWindowPulldownDelegate extends
-        IWorkbenchWindowActionDelegate {
-    /**
-     * Returns the menu for this pull down action.  This method will only be
-     * called if the user opens the pull down menu for the action.   Note that it
-     * is the responsibility of the implementor to properly dispose of any SWT menus
-     * created by this method.
-     *
-     * @return the menu
-     */
-    Menu getMenu(Control parent);
+public interface IWorkbenchWindowPulldownDelegate extends IWorkbenchWindowActionDelegate {
+	/**
+	 * Returns the menu for this pull down action. This method will only be called
+	 * if the user opens the pull down menu for the action. Note that it is the
+	 * responsibility of the implementor to properly dispose of any SWT menus
+	 * created by this method.
+	 *
+	 * @return the menu
+	 */
+	Menu getMenu(Control parent);
 }
