@@ -55,25 +55,19 @@ public class FilteredList extends Composite {
 		/**
 		 * Sets the filter.
 		 *
-		 * @param pattern
-		 *            the filter pattern.
-		 * @param ignoreCase
-		 *            a flag indicating whether pattern matching is case
-		 *            insensitive or not.
-		 * @param ignoreWildCards
-		 *            a flag indicating whether wildcard characters are
-		 *            interpreted or not.
+		 * @param pattern         the filter pattern.
+		 * @param ignoreCase      a flag indicating whether pattern matching is case
+		 *                        insensitive or not.
+		 * @param ignoreWildCards a flag indicating whether wildcard characters are
+		 *                        interpreted or not.
 		 */
-		void setFilter(String pattern, boolean ignoreCase,
-				boolean ignoreWildCards);
+		void setFilter(String pattern, boolean ignoreCase, boolean ignoreWildCards);
 
 		/**
-		 * @param element
-		 *            The element to test against.
+		 * @param element The element to test against.
 		 * @return <code>true</code> if the object matches the pattern,
-		 *         <code>false</code> otherwise. <code>setFilter()</code>
-		 *         must have been called at least once prior to a call to this
-		 *         method.
+		 *         <code>false</code> otherwise. <code>setFilter()</code> must have been
+		 *         called at least once prior to a call to this method.
 		 */
 		boolean match(Object element);
 	}
@@ -82,10 +76,8 @@ public class FilteredList extends Composite {
 		private StringMatcher fMatcher;
 
 		@Override
-		public void setFilter(String pattern, boolean ignoreCase,
-				boolean ignoreWildCards) {
-			fMatcher = new StringMatcher(pattern + '*', ignoreCase,
-					ignoreWildCards);
+		public void setFilter(String pattern, boolean ignoreCase, boolean ignoreWildCards) {
+			fMatcher = new StringMatcher(pattern + '*', ignoreCase, ignoreWildCards);
 		}
 
 		@Override
@@ -195,12 +187,10 @@ public class FilteredList extends Composite {
 			Label rightLabel = (Label) right;
 			int value;
 			if (fComparator == null) {
-				value = labelIgnoreCase ? leftLabel.string
-						.compareToIgnoreCase(rightLabel.string)
+				value = labelIgnoreCase ? leftLabel.string.compareToIgnoreCase(rightLabel.string)
 						: leftLabel.string.compareTo(rightLabel.string);
 			} else {
-				value = fComparator
-						.compare(leftLabel.string, rightLabel.string);
+				value = fComparator.compare(leftLabel.string, rightLabel.string);
 			}
 			if (value != 0) {
 				return value;
@@ -211,8 +201,7 @@ public class FilteredList extends Composite {
 			} else if (rightLabel.image == null) {
 				return +1;
 			} else {
-				return fImages.indexOf(leftLabel.image)
-						- fImages.indexOf(rightLabel.image);
+				return fImages.indexOf(leftLabel.image) - fImages.indexOf(rightLabel.image);
 			}
 		}
 	}
@@ -220,22 +209,16 @@ public class FilteredList extends Composite {
 	/**
 	 * Constructs a new filtered list.
 	 *
-	 * @param parent
-	 *            the parent composite
-	 * @param style
-	 *            the widget style
-	 * @param labelProvider
-	 *            the label renderer
-	 * @param ignoreCase
-	 *            specifies whether sorting and folding is case sensitive
-	 * @param allowDuplicates
-	 *            specifies whether folding of duplicates is desired
-	 * @param matchEmptyString
-	 *            specifies whether empty filter strings should filter
-	 *            everything or nothing
+	 * @param parent           the parent composite
+	 * @param style            the widget style
+	 * @param labelProvider    the label renderer
+	 * @param ignoreCase       specifies whether sorting and folding is case
+	 *                         sensitive
+	 * @param allowDuplicates  specifies whether folding of duplicates is desired
+	 * @param matchEmptyString specifies whether empty filter strings should filter
+	 *                         everything or nothing
 	 */
-	public FilteredList(Composite parent, int style,
-			ILabelProvider labelProvider, boolean ignoreCase,
+	public FilteredList(Composite parent, int style, ILabelProvider labelProvider, boolean ignoreCase,
 			boolean allowDuplicates, boolean matchEmptyString) {
 		super(parent, SWT.NONE);
 		GridLayout layout = new GridLayout();
@@ -261,8 +244,7 @@ public class FilteredList extends Composite {
 	/**
 	 * Sets the list of elements.
 	 *
-	 * @param elements
-	 *            the elements to be shown in the list.
+	 * @param elements the elements to be shown in the list.
 	 */
 	public void setElements(Object[] elements) {
 		if (elements == null) {
@@ -294,8 +276,8 @@ public class FilteredList extends Composite {
 	/**
 	 * Tests if the list (before folding and filtering) is empty.
 	 *
-	 * @return returns <code>true</code> if the list is empty,
-	 *         <code>false</code> otherwise.
+	 * @return returns <code>true</code> if the list is empty, <code>false</code>
+	 *         otherwise.
 	 */
 	public boolean isEmpty() {
 		return (fElements == null) || (fElements.length == 0);
@@ -324,8 +306,7 @@ public class FilteredList extends Composite {
 	/**
 	 * Adds a selection listener to the list.
 	 *
-	 * @param listener
-	 *            the selection listener to be added.
+	 * @param listener the selection listener to be added.
 	 */
 	public void addSelectionListener(SelectionListener listener) {
 		fList.addSelectionListener(listener);
@@ -334,8 +315,7 @@ public class FilteredList extends Composite {
 	/**
 	 * Removes a selection listener from the list.
 	 *
-	 * @param listener
-	 *            the selection listener to be removed.
+	 * @param listener the selection listener to be removed.
 	 */
 	public void removeSelectionListener(SelectionListener listener) {
 		fList.removeSelectionListener(listener);
@@ -344,8 +324,7 @@ public class FilteredList extends Composite {
 	/**
 	 * Sets the selection of the list. Empty or null array removes selection.
 	 *
-	 * @param selection
-	 *            an array of indices specifying the selection.
+	 * @param selection an array of indices specifying the selection.
 	 */
 	public void setSelection(int[] selection) {
 		if (selection == null || selection.length == 0) {
@@ -386,8 +365,7 @@ public class FilteredList extends Composite {
 	/**
 	 * Sets the selection of the list. Empty or null array removes selection.
 	 *
-	 * @param elements
-	 *            the array of elements to be selected.
+	 * @param elements the array of elements to be selected.
 	 */
 	public void setSelection(Object[] elements) {
 		if (elements == null || elements.length == 0) {
@@ -402,8 +380,7 @@ public class FilteredList extends Composite {
 		for (int i = 0; i != elements.length; i++) {
 			int j;
 			for (j = 0; j != fFoldedCount; j++) {
-				int max = (j == fFoldedCount - 1) ? fFilteredCount
-						: fFoldedIndices[j + 1];
+				int max = (j == fFoldedCount - 1) ? fFilteredCount : fFoldedIndices[j + 1];
 				int l;
 				for (l = fFoldedIndices[j]; l != max; l++) {
 					// found matching element?
@@ -425,10 +402,9 @@ public class FilteredList extends Composite {
 	}
 
 	/**
-	 * Returns an array of the selected elements. The type of the elements
-	 * returned in the list are the same as the ones passed with
-	 * <code>setElements</code>. The array does not contain the rendered
-	 * strings.
+	 * Returns an array of the selected elements. The type of the elements returned
+	 * in the list are the same as the ones passed with <code>setElements</code>.
+	 * The array does not contain the rendered strings.
 	 *
 	 * @return returns the array of selected elements.
 	 */
@@ -445,11 +421,9 @@ public class FilteredList extends Composite {
 	}
 
 	/**
-	 * Sets the filter pattern. Current only prefix filter patterns are
-	 * supported.
+	 * Sets the filter pattern. Current only prefix filter patterns are supported.
 	 *
-	 * @param filter
-	 *            the filter pattern.
+	 * @param filter the filter pattern.
 	 */
 	public void setFilter(String filter) {
 		fFilter = (filter == null) ? "" : filter; //$NON-NLS-1$
@@ -478,18 +452,16 @@ public class FilteredList extends Composite {
 	/**
 	 * Returns all elements which are folded together to one entry in the list.
 	 *
-	 * @param index
-	 *            the index selecting the entry in the list.
-	 * @return returns an array of elements folded together, <code>null</code>
-	 *         if index is out of range.
+	 * @param index the index selecting the entry in the list.
+	 * @return returns an array of elements folded together, <code>null</code> if
+	 *         index is out of range.
 	 */
 	public Object[] getFoldedElements(int index) {
 		if ((index < 0) || (index >= fFoldedCount)) {
 			return null;
 		}
 		int start = fFoldedIndices[index];
-		int count = (index == fFoldedCount - 1) ? fFilteredCount - start
-				: fFoldedIndices[index + 1] - start;
+		int count = (index == fFoldedCount - 1) ? fFilteredCount - start : fFoldedIndices[index + 1] - start;
 		Object[] elements = new Object[count];
 		for (int i = 0; i != count; i++) {
 			elements[i] = fElements[fFilteredIndices[start + i]];
@@ -498,9 +470,9 @@ public class FilteredList extends Composite {
 	}
 
 	/*
-	 * Folds duplicate entries. Two elements are considered as a pair of
-	 * duplicates if they coiincide in the rendered string and image. @return
-	 * returns the number of elements after folding.
+	 * Folds duplicate entries. Two elements are considered as a pair of duplicates
+	 * if they coiincide in the rendered string and image. @return returns the
+	 * number of elements after folding.
 	 */
 	private int fold() {
 		if (fAllowDuplicates) {
@@ -528,8 +500,7 @@ public class FilteredList extends Composite {
 	 * elements after filtering.
 	 */
 	private int filter() {
-		if (((fFilter == null) || (fFilter.length() == 0))
-				&& !fMatchEmptyString) {
+		if (((fFilter == null) || (fFilter.length() == 0)) && !fMatchEmptyString) {
 			return 0;
 		}
 		fFilterMatcher.setFilter(fFilter.trim(), fIgnoreCase, false);
@@ -560,8 +531,7 @@ public class FilteredList extends Composite {
 		 * Create a new instance of a job used to update the table.
 		 *
 		 * @param table
-		 * @param count
-		 *            The number of items to update per running.
+		 * @param count The number of items to update per running.
 		 */
 		public TableUpdateJob(Table table, int count) {
 			super(WorkbenchMessages.FilteredList_UpdateJobName);
@@ -570,70 +540,70 @@ public class FilteredList extends Composite {
 			fCount = count;
 		}
 
-@Override
-public IStatus runInUIThread(IProgressMonitor monitor) {
-            if (fTable.isDisposed()) {
+		@Override
+		public IStatus runInUIThread(IProgressMonitor monitor) {
+			if (fTable.isDisposed()) {
 				return Status.CANCEL_STATUS;
 			}
-            int itemCount = fTable.getItemCount();
+			int itemCount = fTable.getItemCount();
 
-            // Remove excess items
-            if (fCount < itemCount) {
-                fTable.setRedraw(false);
-                fTable.remove(fCount, itemCount - 1);
-                fTable.setRedraw(true);
-                itemCount = fTable.getItemCount();
-            }
-            // table empty -> no selection
-            if (fCount == 0) {
-                fTable.notifyListeners(SWT.Selection, new Event());
-                return Status.OK_STATUS;
-            }
-            // How many we are going to do this time.
-            int iterations = Math.min(10, fCount - currentIndex);
-            for (int i = 0; i < iterations; i++) {
-                if (monitor.isCanceled()) {
+			// Remove excess items
+			if (fCount < itemCount) {
+				fTable.setRedraw(false);
+				fTable.remove(fCount, itemCount - 1);
+				fTable.setRedraw(true);
+				itemCount = fTable.getItemCount();
+			}
+			// table empty -> no selection
+			if (fCount == 0) {
+				fTable.notifyListeners(SWT.Selection, new Event());
+				return Status.OK_STATUS;
+			}
+			// How many we are going to do this time.
+			int iterations = Math.min(10, fCount - currentIndex);
+			for (int i = 0; i < iterations; i++) {
+				if (monitor.isCanceled()) {
 					return Status.CANCEL_STATUS;
 				}
-                final TableItem item = (currentIndex < itemCount) ? fTable
-                        .getItem(currentIndex)
-                        : new TableItem(fTable, SWT.NONE);
-                final Label label = fLabels[fFilteredIndices[fFoldedIndices[currentIndex]]];
-                item.setText(label.string);
-                item.setImage(label.image);
-                currentIndex++;
-            }
-            if (monitor.isCanceled()) {
+				final TableItem item = (currentIndex < itemCount) ? fTable.getItem(currentIndex)
+						: new TableItem(fTable, SWT.NONE);
+				final Label label = fLabels[fFilteredIndices[fFoldedIndices[currentIndex]]];
+				item.setText(label.string);
+				item.setImage(label.image);
+				currentIndex++;
+			}
+			if (monitor.isCanceled()) {
 				return Status.CANCEL_STATUS;
 			}
-            if (currentIndex < fCount) {
+			if (currentIndex < fCount) {
 				schedule(100);
 			} else {
-                if (indicesToSelect == null) {
-                 	// Make a default selection in the table if there is none.
-                	// If a selection has already been made, honor it.
-                	// See https://bugs.eclipse.org/bugs/show_bug.cgi?id=112146
-                    if (fCount > 0) {
-                    	if (fTable.getSelectionIndices().length == 0) {
-                    		defaultSelect();
-                    	} else {
-                    		// There is a selection, but it likely hasn't changed since the
-                    		// job started.  Force a selection notification, since the
-                    		// items represented by the selection have changed.
+				if (indicesToSelect == null) {
+					// Make a default selection in the table if there is none.
+					// If a selection has already been made, honor it.
+					// See https://bugs.eclipse.org/bugs/show_bug.cgi?id=112146
+					if (fCount > 0) {
+						if (fTable.getSelectionIndices().length == 0) {
+							defaultSelect();
+						} else {
+							// There is a selection, but it likely hasn't changed since the
+							// job started. Force a selection notification, since the
+							// items represented by the selection have changed.
 							// See https://bugs.eclipse.org/bugs/show_bug.cgi?id=119456
-                    		fTable.notifyListeners(SWT.Selection, new Event());
-                    	}
-                    }
-                } else {
-                	// Set the selection as indicated.
-                    selectAndNotify(indicesToSelect);
-                }
-                // This flag signifies that the selection can now be directly
-                // updated in the widget.
-                readyForSelection = true;
-            }
-            return Status.OK_STATUS;
-        }
+							fTable.notifyListeners(SWT.Selection, new Event());
+						}
+					}
+				} else {
+					// Set the selection as indicated.
+					selectAndNotify(indicesToSelect);
+				}
+				// This flag signifies that the selection can now be directly
+				// updated in the widget.
+				readyForSelection = true;
+			}
+			return Status.OK_STATUS;
+		}
+
 		/**
 		 * Update the selection for the supplied indices.
 		 *
@@ -682,11 +652,10 @@ public IStatus runInUIThread(IProgressMonitor monitor) {
 	}
 
 	/**
-	 * Sets whether or not duplicates are allowed. If this value is set the
-	 * items should be set again for this value to take effect.
+	 * Sets whether or not duplicates are allowed. If this value is set the items
+	 * should be set again for this value to take effect.
 	 *
-	 * @param allowDuplicates
-	 *            <code>true</code> indicates duplicates are allowed
+	 * @param allowDuplicates <code>true</code> indicates duplicates are allowed
 	 */
 	public void setAllowDuplicates(boolean allowDuplicates) {
 		this.fAllowDuplicates = allowDuplicates;
@@ -705,8 +674,7 @@ public IStatus runInUIThread(IProgressMonitor monitor) {
 	 * Sets whether or not case should be ignored If this value is set the items
 	 * should be set again for this value to take effect.
 	 *
-	 * @param ignoreCase
-	 *            <code>true</code> if case should be ignored
+	 * @param ignoreCase <code>true</code> if case should be ignored
 	 */
 	public void setIgnoreCase(boolean ignoreCase) {
 		this.fIgnoreCase = ignoreCase;
@@ -727,9 +695,8 @@ public IStatus runInUIThread(IProgressMonitor monitor) {
 	 * this value is set the items should be set again for this value to take
 	 * effect.
 	 *
-	 * @param matchEmptyString
-	 *            <code>true</code> for the empty string to match all items,
-	 *            <code>false</code> to match none
+	 * @param matchEmptyString <code>true</code> for the empty string to match all
+	 *                         items, <code>false</code> to match none
 	 */
 	public void setMatchEmptyString(boolean matchEmptyString) {
 		this.fMatchEmptyString = matchEmptyString;
@@ -745,27 +712,28 @@ public IStatus runInUIThread(IProgressMonitor monitor) {
 	}
 
 	/**
-	 * Sets the label provider. If this value is set the items should be set
-	 * again for this value to take effect.
+	 * Sets the label provider. If this value is set the items should be set again
+	 * for this value to take effect.
 	 *
-	 * @param labelProvider
-	 *            the label provider
+	 * @param labelProvider the label provider
 	 */
 	public void setLabelProvider(ILabelProvider labelProvider) {
 		this.fLabelProvider = labelProvider;
 	}
 
 	/**
-	 * Returns the accessible object for the receiver.
-	 * If this is the first time this object is requested,
-	 * then the object is created and returned.
+	 * Returns the accessible object for the receiver. If this is the first time
+	 * this object is requested, then the object is created and returned.
 	 *
 	 * @return the accessible object
 	 *
-	 * @exception SWTException <ul>
-	 *    <li>ERROR_WIDGET_DISPOSED - if the receiver has been disposed</li>
-	 *    <li>ERROR_THREAD_INVALID_ACCESS - if not called from the thread that created the receiver</li>
-	 * </ul>
+	 * @exception SWTException
+	 *                         <ul>
+	 *                         <li>ERROR_WIDGET_DISPOSED - if the receiver has been
+	 *                         disposed</li>
+	 *                         <li>ERROR_THREAD_INVALID_ACCESS - if not called from
+	 *                         the thread that created the receiver</li>
+	 *                         </ul>
 	 *
 	 * @see Accessible#addAccessibleListener
 	 * @see Accessible#addAccessibleControlListener
