@@ -31,8 +31,8 @@ public class SearchPattern {
 
 	// Rules for pattern matching: (exact, prefix, pattern) [ | case sensitive]
 	/**
-	 * Match rule: The search pattern matches exactly the search result, that
-	 * is, the source of the search result equals the search pattern. Search pattern
+	 * Match rule: The search pattern matches exactly the search result, that is,
+	 * the source of the search result equals the search pattern. Search pattern
 	 * should start from lowerCase char.
 	 */
 	public static final int RULE_EXACT_MATCH = 0;
@@ -43,17 +43,16 @@ public class SearchPattern {
 	public static final int RULE_PREFIX_MATCH = 0x0001;
 
 	/**
-	 * Match rule: The search pattern contains one or more wild cards ('*' or
-	 * '?'). A '*' wild-card can replace 0 or more characters in the search
-	 * result. A '?' wild-card replaces exactly 1 character in the search
-	 * result.
+	 * Match rule: The search pattern contains one or more wild cards ('*' or '?').
+	 * A '*' wild-card can replace 0 or more characters in the search result. A '?'
+	 * wild-card replaces exactly 1 character in the search result.
 	 */
 	public static final int RULE_PATTERN_MATCH = 0x0002;
 
 	/**
-	 * Match rule: The search pattern matches the search result only if cases
-	 * are the same. Can be combined with previous rules, e.g.
-	 * {@link #RULE_EXACT_MATCH} | {@link #RULE_CASE_SENSITIVE}
+	 * Match rule: The search pattern matches the search result only if cases are
+	 * the same. Can be combined with previous rules, e.g. {@link #RULE_EXACT_MATCH}
+	 * | {@link #RULE_CASE_SENSITIVE}
 	 */
 	public static final int RULE_CASE_SENSITIVE = 0x0008;
 
@@ -67,25 +66,25 @@ public class SearchPattern {
 	 * Examples:
 	 * <ul>
 	 * <li><code>NPE</code> type string pattern will match
-	 * <code>NullPointerException</code> and
-	 * <code>NpPermissionException</code> types,</li>
+	 * <code>NullPointerException</code> and <code>NpPermissionException</code>
+	 * types,</li>
 	 * <li><code>NuPoEx</code> type string pattern will only match
 	 * <code>NullPointerException</code> type.</li>
 	 * </ul>
 	 *
 	 *
 	 * <br>
-	 * Can be combined with {@link #RULE_PREFIX_MATCH} match rule. For example,
-	 * when prefix match rule is combined with Camel Case match rule,
-	 * <code>"nPE"</code> pattern will match <code>nPException</code>. <br>
-	 * Match rule {@link #RULE_PATTERN_MATCH} may also be combined but both
-	 * rules will not be used simultaneously as they are mutually exclusive.
-	 * Used match rule depends on whether string pattern contains specific
-	 * pattern characters (e.g. '*' or '?') or not. If it does, then only
-	 * Pattern match rule will be used, otherwise only Camel Case match will be
-	 * used. For example, with <code>"NPE"</code> string pattern, search will
-	 * only use Camel Case match rule, but with <code>N*P*E*</code> string
-	 * pattern, it will use only Pattern match rule.
+	 * Can be combined with {@link #RULE_PREFIX_MATCH} match rule. For example, when
+	 * prefix match rule is combined with Camel Case match rule, <code>"nPE"</code>
+	 * pattern will match <code>nPException</code>. <br>
+	 * Match rule {@link #RULE_PATTERN_MATCH} may also be combined but both rules
+	 * will not be used simultaneously as they are mutually exclusive. Used match
+	 * rule depends on whether string pattern contains specific pattern characters
+	 * (e.g. '*' or '?') or not. If it does, then only Pattern match rule will be
+	 * used, otherwise only Camel Case match will be used. For example, with
+	 * <code>"NPE"</code> string pattern, search will only use Camel Case match
+	 * rule, but with <code>N*P*E*</code> string pattern, it will use only Pattern
+	 * match rule.
 	 *
 	 */
 	public static final int RULE_CAMELCASE_MATCH = 0x0080;
@@ -114,28 +113,28 @@ public class SearchPattern {
 	 *
 	 */
 	public SearchPattern() {
-		this(RULE_EXACT_MATCH | RULE_PREFIX_MATCH | RULE_PATTERN_MATCH
-				| RULE_CAMELCASE_MATCH | RULE_BLANK_MATCH);
+		this(RULE_EXACT_MATCH | RULE_PREFIX_MATCH | RULE_PATTERN_MATCH | RULE_CAMELCASE_MATCH | RULE_BLANK_MATCH);
 	}
 
 	/**
-	 * Creates a search pattern with the rule to apply for matching index keys.
-	 * It can be exact match, prefix match, pattern match or camelCase match.
-	 * Rule can also be combined with a case sensitivity flag.
+	 * Creates a search pattern with the rule to apply for matching index keys. It
+	 * can be exact match, prefix match, pattern match or camelCase match. Rule can
+	 * also be combined with a case sensitivity flag.
 	 *
-	 * @param allowedRules
-	 *            one of {@link #RULE_EXACT_MATCH}, {@link #RULE_PREFIX_MATCH},
-	 *            {@link #RULE_PATTERN_MATCH}, {@link #RULE_CASE_SENSITIVE},
-	 *            {@link #RULE_CAMELCASE_MATCH} combined with one of following
-	 *            values: {@link #RULE_EXACT_MATCH}, {@link #RULE_PREFIX_MATCH},
-	 *            {@link #RULE_PATTERN_MATCH} or {@link #RULE_CAMELCASE_MATCH}.
-	 *            e.g. {@link #RULE_EXACT_MATCH} | {@link #RULE_CASE_SENSITIVE}
-	 *            if an exact and case sensitive match is requested,
-	 *            {@link #RULE_PREFIX_MATCH} if a prefix non case sensitive
-	 *            match is requested or {@link #RULE_EXACT_MATCH} if a non case
-	 *            sensitive and erasure match is requested.<br>
-	 *            Note also that default behavior for generic types/methods
-	 *            search is to find exact matches.
+	 * @param allowedRules one of {@link #RULE_EXACT_MATCH},
+	 *                     {@link #RULE_PREFIX_MATCH}, {@link #RULE_PATTERN_MATCH},
+	 *                     {@link #RULE_CASE_SENSITIVE},
+	 *                     {@link #RULE_CAMELCASE_MATCH} combined with one of
+	 *                     following values: {@link #RULE_EXACT_MATCH},
+	 *                     {@link #RULE_PREFIX_MATCH}, {@link #RULE_PATTERN_MATCH}
+	 *                     or {@link #RULE_CAMELCASE_MATCH}. e.g.
+	 *                     {@link #RULE_EXACT_MATCH} | {@link #RULE_CASE_SENSITIVE}
+	 *                     if an exact and case sensitive match is requested,
+	 *                     {@link #RULE_PREFIX_MATCH} if a prefix non case sensitive
+	 *                     match is requested or {@link #RULE_EXACT_MATCH} if a non
+	 *                     case sensitive and erasure match is requested.<br>
+	 *                     Note also that default behavior for generic types/methods
+	 *                     search is to find exact matches.
 	 */
 	public SearchPattern(int allowedRules) {
 		this.allowedRules = allowedRules;
@@ -151,8 +150,7 @@ public class SearchPattern {
 	}
 
 	/**
-	 * @param stringPattern
-	 *            The stringPattern to set.
+	 * @param stringPattern The stringPattern to set.
 	 */
 	public void setPattern(String stringPattern) {
 		this.initialPattern = stringPattern;
@@ -183,7 +181,7 @@ public class SearchPattern {
 				return true;
 			}
 			//$FALL-THROUGH$
-			default:
+		default:
 			return startsWithIgnoreCase(text, stringPattern);
 		}
 	}
@@ -233,8 +231,8 @@ public class SearchPattern {
 	/**
 	 * @param text
 	 * @param prefix
-	 * @return true if text starts with given prefix, ignoring case false in
-	 *         other way
+	 * @return true if text starts with given prefix, ignoring case false in other
+	 *         way
 	 */
 	private boolean startsWithIgnoreCase(String text, String prefix) {
 		int textLength = text.length();
@@ -242,31 +240,30 @@ public class SearchPattern {
 		if (textLength < prefixLength)
 			return false;
 		for (int i = prefixLength - 1; i >= 0; i--) {
-			if (Character.toLowerCase(prefix.charAt(i)) != Character
-					.toLowerCase(text.charAt(i)))
+			if (Character.toLowerCase(prefix.charAt(i)) != Character.toLowerCase(text.charAt(i)))
 				return false;
 		}
 		return true;
 	}
 
 	/**
-	 * Answers true if the pattern matches the given name using CamelCase rules,
-	 * or false otherwise. CamelCase matching does NOT accept explicit
-	 * wild-cards '*' and '?' and is inherently case sensitive. <br>
-	 * CamelCase denotes the convention of writing compound names without
-	 * spaces, and capitalizing every term. This function recognizes both upper
-	 * and lower CamelCase, depending whether the leading character is
-	 * capitalized or not. The leading part of an upper CamelCase pattern is
-	 * assumed to contain a sequence of capitals which are appearing in the
-	 * matching name; e.g. 'NPE' will match 'NullPointerException', but not
-	 * 'NewPerfData'. A lower CamelCase pattern uses a lowercase first
-	 * character. In Java, type names follow the upper CamelCase convention,
-	 * whereas method or field names follow the lower CamelCase convention. <br>
-	 * The pattern may contain lowercase characters, which will be match in a
-	 * case sensitive way. These characters must appear in sequence in the name.
-	 * For instance, 'NPExcep' will match 'NullPointerException', but not
-	 * 'NullPointerExCEPTION' or 'NuPoEx' will match 'NullPointerException', but
-	 * not 'NoPointerException'. <br>
+	 * Answers true if the pattern matches the given name using CamelCase rules, or
+	 * false otherwise. CamelCase matching does NOT accept explicit wild-cards '*'
+	 * and '?' and is inherently case sensitive. <br>
+	 * CamelCase denotes the convention of writing compound names without spaces,
+	 * and capitalizing every term. This function recognizes both upper and lower
+	 * CamelCase, depending whether the leading character is capitalized or not. The
+	 * leading part of an upper CamelCase pattern is assumed to contain a sequence
+	 * of capitals which are appearing in the matching name; e.g. 'NPE' will match
+	 * 'NullPointerException', but not 'NewPerfData'. A lower CamelCase pattern uses
+	 * a lowercase first character. In Java, type names follow the upper CamelCase
+	 * convention, whereas method or field names follow the lower CamelCase
+	 * convention. <br>
+	 * The pattern may contain lowercase characters, which will be match in a case
+	 * sensitive way. These characters must appear in sequence in the name. For
+	 * instance, 'NPExcep' will match 'NullPointerException', but not
+	 * 'NullPointerExCEPTION' or 'NuPoEx' will match 'NullPointerException', but not
+	 * 'NoPointerException'. <br>
 	 * <br>
 	 * Examples:
 	 * <ol>
@@ -299,10 +296,8 @@ public class SearchPattern {
 	 * </li>
 	 * </ol>
 	 *
-	 * @param pattern
-	 *            the given pattern
-	 * @param name
-	 *            the given name
+	 * @param pattern the given pattern
+	 * @param name    the given name
 	 * @return true if the pattern matches the given name, false otherwise
 	 *
 	 */
@@ -312,31 +307,29 @@ public class SearchPattern {
 		if (name == null)
 			return false; // null name cannot match
 
-		return camelCaseMatch(pattern, 0, pattern.length(), name, 0, name
-				.length());
+		return camelCaseMatch(pattern, 0, pattern.length(), name, 0, name.length());
 	}
 
 	/**
 	 * Answers true if a sub-pattern matches the subpart of the given name using
 	 * CamelCase rules, or false otherwise. CamelCase matching does NOT accept
-	 * explicit wild-cards '*' and '?' and is inherently case sensitive. Can
-	 * match only subset of name/pattern, considering end positions as
-	 * non-inclusive. The subpattern is defined by the patternStart and
-	 * patternEnd positions. <br>
-	 * CamelCase denotes the convention of writing compound names without
-	 * spaces, and capitalizing every term. This function recognizes both upper
-	 * and lower CamelCase, depending whether the leading character is
-	 * capitalized or not. The leading part of an upper CamelCase pattern is
-	 * assumed to contain a sequence of capitals which are appearing in the
-	 * matching name; e.g. 'NPE' will match 'NullPointerException', but not
-	 * 'NewPerfData'. A lower CamelCase pattern uses a lowercase first
-	 * character. In Java, type names follow the upper CamelCase convention,
-	 * whereas method or field names follow the lower CamelCase convention. <br>
-	 * The pattern may contain lowercase characters, which will be match in a
-	 * case sensitive way. These characters must appear in sequence in the name.
-	 * For instance, 'NPExcep' will match 'NullPointerException', but not
-	 * 'NullPointerExCEPTION' or 'NuPoEx' will match 'NullPointerException', but
-	 * not 'NoPointerException'. <br>
+	 * explicit wild-cards '*' and '?' and is inherently case sensitive. Can match
+	 * only subset of name/pattern, considering end positions as non-inclusive. The
+	 * subpattern is defined by the patternStart and patternEnd positions. <br>
+	 * CamelCase denotes the convention of writing compound names without spaces,
+	 * and capitalizing every term. This function recognizes both upper and lower
+	 * CamelCase, depending whether the leading character is capitalized or not. The
+	 * leading part of an upper CamelCase pattern is assumed to contain a sequence
+	 * of capitals which are appearing in the matching name; e.g. 'NPE' will match
+	 * 'NullPointerException', but not 'NewPerfData'. A lower CamelCase pattern uses
+	 * a lowercase first character. In Java, type names follow the upper CamelCase
+	 * convention, whereas method or field names follow the lower CamelCase
+	 * convention. <br>
+	 * The pattern may contain lowercase characters, which will be match in a case
+	 * sensitive way. These characters must appear in sequence in the name. For
+	 * instance, 'NPExcep' will match 'NullPointerException', but not
+	 * 'NullPointerExCEPTION' or 'NuPoEx' will match 'NullPointerException', but not
+	 * 'NoPointerException'. <br>
 	 * <br>
 	 * Examples:
 	 * <ol>
@@ -407,23 +400,17 @@ public class SearchPattern {
 	 * </li>
 	 * </ol>
 	 *
-	 * @param pattern
-	 *            the given pattern
-	 * @param patternStart
-	 *            the start index of the pattern, inclusive
-	 * @param patternEnd
-	 *            the end index of the pattern, exclusive
-	 * @param name
-	 *            the given name
-	 * @param nameStart
-	 *            the start index of the name, inclusive
-	 * @param nameEnd
-	 *            the end index of the name, exclusive
-	 * @return true if a sub-pattern matches the subpart of the given name,
-	 *         false otherwise
+	 * @param pattern      the given pattern
+	 * @param patternStart the start index of the pattern, inclusive
+	 * @param patternEnd   the end index of the pattern, exclusive
+	 * @param name         the given name
+	 * @param nameStart    the start index of the name, inclusive
+	 * @param nameEnd      the end index of the name, exclusive
+	 * @return true if a sub-pattern matches the subpart of the given name, false
+	 *         otherwise
 	 */
-	private boolean camelCaseMatch(String pattern, int patternStart,
-			int patternEnd, String name, int nameStart, int nameEnd) {
+	private boolean camelCaseMatch(String pattern, int patternStart, int patternEnd, String name, int nameStart,
+			int nameEnd) {
 		if (name == null)
 			return false; // null name cannot match
 		if (pattern == null)
@@ -445,10 +432,9 @@ public class SearchPattern {
 
 		int patternLength = patternEnd;
 
-		if (pattern.charAt(patternEnd - 1) == END_SYMBOL || pattern.charAt(patternEnd - 1) == BLANK )
+		if (pattern.charAt(patternEnd - 1) == END_SYMBOL || pattern.charAt(patternEnd - 1) == BLANK)
 			patternLength = patternEnd - 1;
 
-
 		char patternChar, nameChar;
 		int iPattern = patternStart;
 		int iName = nameStart;
@@ -459,7 +445,7 @@ public class SearchPattern {
 			iPattern++;
 			iName++;
 
-				if (iPattern == patternEnd) {
+			if (iPattern == patternEnd) {
 				// We have exhausted pattern, so it's a match
 				return true;
 			}
@@ -502,13 +488,15 @@ public class SearchPattern {
 				}
 
 				if (Character.isDigit(nameChar)) {
-					// nameChar is digit => break if the digit is current pattern character otherwise consume it
-					if (patternChar == nameChar) break;
+					// nameChar is digit => break if the digit is current pattern character
+					// otherwise consume it
+					if (patternChar == nameChar)
+						break;
 					iName++;
 				} else if (!isNameCharAllowed(nameChar)) {
 					// nameChar is lowercase
 					iName++;
-				// nameChar is uppercase...
+					// nameChar is uppercase...
 				} else if (patternChar != nameChar) {
 					// .. and it does not match patternChar, so it's not a match
 					return false;
@@ -524,23 +512,22 @@ public class SearchPattern {
 	}
 
 	/**
-	 * Checks pattern's character is allowed for specified set. It could be
-	 * override if you want change logic of camelCaseMatch methods.
+	 * Checks pattern's character is allowed for specified set. It could be override
+	 * if you want change logic of camelCaseMatch methods.
 	 *
 	 * @param patternChar
 	 * @return true if patternChar is in set of allowed characters for pattern
 	 */
 	protected boolean isPatternCharAllowed(char patternChar) {
-		return patternChar == END_SYMBOL || patternChar == BLANK
-			|| Character.isUpperCase(patternChar) || Character.isDigit(patternChar);
+		return patternChar == END_SYMBOL || patternChar == BLANK || Character.isUpperCase(patternChar)
+				|| Character.isDigit(patternChar);
 	}
 
 	/**
-	 * Checks character of element's name is allowed for specified set. It could
-	 * be override if you want change logic of camelCaseMatch methods.
+	 * Checks character of element's name is allowed for specified set. It could be
+	 * override if you want change logic of camelCaseMatch methods.
 	 *
-	 * @param nameChar -
-	 *            name of searched element
+	 * @param nameChar - name of searched element
 	 * @return if nameChar is in set of allowed characters for name of element
 	 */
 	protected boolean isNameCharAllowed(char nameChar) {
@@ -554,9 +541,9 @@ public class SearchPattern {
 	 *
 	 * @return one of RULE_EXACT_MATCH, RULE_PREFIX_MATCH, RULE_PATTERN_MATCH,
 	 *         RULE_CAMELCASE_MATCH, combined with RULE_CASE_SENSITIVE, e.g.
-	 *         RULE_EXACT_MATCH | RULE_CASE_SENSITIVE if an exact and case
-	 *         sensitive match is requested, or RULE_PREFIX_MATCH if a prefix
-	 *         non case sensitive match is requested.
+	 *         RULE_EXACT_MATCH | RULE_CASE_SENSITIVE if an exact and case sensitive
+	 *         match is requested, or RULE_PREFIX_MATCH if a prefix non case
+	 *         sensitive match is requested.
 	 */
 	public final int getMatchRule() {
 		return this.matchRule;
@@ -566,17 +553,19 @@ public class SearchPattern {
 	 * Validate compatibility between given string pattern and match rule. <br>
 	 * Optimized (ie. returned match rule is modified) combinations are:
 	 * <ul>
-	 * <li>{@link #RULE_PATTERN_MATCH} without any '*' or '?' in string pattern: pattern match bit
-	 * is unset,</li>
-	 * <li>{@link #RULE_PATTERN_MATCH} and {@link #RULE_PREFIX_MATCH} bits simultaneously set:
-	 * prefix match bit is unset,</li>
-	 * <li>{@link #RULE_PATTERN_MATCH} and {@link #RULE_CAMELCASE_MATCH} bits simultaneously set:
-	 * camel case match bit is unset,</li>
-	 * <li>{@link #RULE_CAMELCASE_MATCH} with invalid combination of uppercase and lowercase
-	 * characters: camel case match bit is unset and replaced with prefix match pattern,</li>
-	 * <li>{@link #RULE_CAMELCASE_MATCH} combined with {@link #RULE_PREFIX_MATCH} and
-	 * {@link #RULE_CASE_SENSITIVE} bits is reduced to only {@link #RULE_CAMELCASE_MATCH} as Camel
-	 * Case search is already prefix and case sensitive,</li>
+	 * <li>{@link #RULE_PATTERN_MATCH} without any '*' or '?' in string pattern:
+	 * pattern match bit is unset,</li>
+	 * <li>{@link #RULE_PATTERN_MATCH} and {@link #RULE_PREFIX_MATCH} bits
+	 * simultaneously set: prefix match bit is unset,</li>
+	 * <li>{@link #RULE_PATTERN_MATCH} and {@link #RULE_CAMELCASE_MATCH} bits
+	 * simultaneously set: camel case match bit is unset,</li>
+	 * <li>{@link #RULE_CAMELCASE_MATCH} with invalid combination of uppercase and
+	 * lowercase characters: camel case match bit is unset and replaced with prefix
+	 * match pattern,</li>
+	 * <li>{@link #RULE_CAMELCASE_MATCH} combined with {@link #RULE_PREFIX_MATCH}
+	 * and {@link #RULE_CASE_SENSITIVE} bits is reduced to only
+	 * {@link #RULE_CAMELCASE_MATCH} as Camel Case search is already prefix and case
+	 * sensitive,</li>
 	 * </ul>
 	 * <br>
 	 * Rejected (ie. returned match rule -1) combinations are:
@@ -585,7 +574,7 @@ public class SearchPattern {
 	 * </ul>
 	 *
 	 * @param stringPattern The string pattern
-	 * @param matchRule The match rule
+	 * @param matchRule     The match rule
 	 * @return Optimized valid match rule or -1 if an incompatibility was detected.
 	 */
 	private int validateMatchRule(String stringPattern, int matchRule) {
@@ -639,8 +628,7 @@ public class SearchPattern {
 	/**
 	 * Check if character is valid camelCase character
 	 *
-	 * @param ch
-	 *            character to be validated
+	 * @param ch character to be validated
 	 * @return true if character is valid
 	 */
 	protected boolean isValidCamelCaseChar(char ch) {
@@ -650,43 +638,37 @@ public class SearchPattern {
 	/**
 	 * Tells whether the given <code>SearchPattern</code> equals this pattern.
 	 *
-	 * @param pattern
-	 *            pattern to be checked
+	 * @param pattern pattern to be checked
 	 * @return true if the given pattern equals this search pattern
 	 */
 	public boolean equalsPattern(SearchPattern pattern) {
-		return trimWildcardCharacters(pattern.initialPattern).equals(
-				trimWildcardCharacters(this.initialPattern));
+		return trimWildcardCharacters(pattern.initialPattern).equals(trimWildcardCharacters(this.initialPattern));
 	}
 
 	/**
-	 * Tells whether the given <code>SearchPattern</code> is a sub-pattern of
-	 * this pattern.
+	 * Tells whether the given <code>SearchPattern</code> is a sub-pattern of this
+	 * pattern.
 	 * <p>
 	 * <i>WARNING: This method is <b>not</b> defined in reading order, i.e.
-	 * <code>a.isSubPattern(b)</code> is <code>true</code> iff
-	 * <code>b</code> is a sub-pattern of <code>a</code>, and not vice-versa.
-	 * </i>
+	 * <code>a.isSubPattern(b)</code> is <code>true</code> iff <code>b</code> is a
+	 * sub-pattern of <code>a</code>, and not vice-versa. </i>
 	 * </p>
 	 *
-	 * @param pattern
-	 *            pattern to be checked
+	 * @param pattern pattern to be checked
 	 * @return true if the given pattern is a sub pattern of this search pattern
 	 */
 	public boolean isSubPattern(SearchPattern pattern) {
-		return trimWildcardCharacters(pattern.initialPattern).startsWith(
-				trimWildcardCharacters(this.initialPattern));
+		return trimWildcardCharacters(pattern.initialPattern).startsWith(trimWildcardCharacters(this.initialPattern));
 	}
 
 	/**
 	 * Trims sequences of '*' characters
 	 *
-	 * @param pattern
-	 *            string to be trimmed
+	 * @param pattern string to be trimmed
 	 * @return trimmed pattern
 	 */
 	private String trimWildcardCharacters(String pattern) {
-		return Util.replaceAll(pattern, "\\*+", "\\*"); //$NON-NLS-1$ //$NON-NLS-2$		}
+		return Util.replaceAll(pattern, "\\*+", "\\*"); //$NON-NLS-1$ //$NON-NLS-2$ }
 	}
 
 }
