@@ -124,10 +124,8 @@ public class ModeledPageLayout implements IPageLayout {
 		}
 	}
 
-	public ModeledPageLayout(MWindow window, EModelService modelService,
-			EPartService partService,
-			MPerspective perspModel, IPerspectiveDescriptor descriptor, WorkbenchPage page,
-			boolean createReferences) {
+	public ModeledPageLayout(MWindow window, EModelService modelService, EPartService partService,
+			MPerspective perspModel, IPerspectiveDescriptor descriptor, WorkbenchPage page, boolean createReferences) {
 		// this.window = window;
 		MUIElement winParent = window.getParent();
 		this.application = (MApplication) winParent;
@@ -221,8 +219,7 @@ public class ModeledPageLayout implements IPageLayout {
 	}
 
 	@Override
-	public void addPlaceholder(String viewId, int relationship, float ratio,
-			String refId) {
+	public void addPlaceholder(String viewId, int relationship, float ratio, String refId) {
 		insertView(viewId, relationship, ratio, refId, false, true);
 	}
 
@@ -237,8 +234,7 @@ public class ModeledPageLayout implements IPageLayout {
 	}
 
 	@Override
-	public void addStandaloneView(String viewId, boolean showTitle,
-			int relationship, float ratio, String refId) {
+	public void addStandaloneView(String viewId, boolean showTitle, int relationship, float ratio, String refId) {
 		MUIElement newElement = insertView(viewId, relationship, ratio, refId, true, showTitle);
 		if (newElement instanceof MPartStack) {
 			MPartStack stack = (MPartStack) newElement;
@@ -250,8 +246,8 @@ public class ModeledPageLayout implements IPageLayout {
 	}
 
 	@Override
-	public void addStandaloneViewPlaceholder(String viewId, int relationship,
-			float ratio, String refId, boolean showTitle) {
+	public void addStandaloneViewPlaceholder(String viewId, int relationship, float ratio, String refId,
+			boolean showTitle) {
 		MUIElement newElement = insertView(viewId, relationship, ratio, refId, false, showTitle);
 		if (newElement instanceof MPartStack) {
 			MPartStack stack = (MPartStack) newElement;
@@ -267,8 +263,7 @@ public class ModeledPageLayout implements IPageLayout {
 		insertView(viewId, relationship, ratio, refId, true, true);
 	}
 
-	public void addView(String viewId, int relationship, float ratio, String refId,
-			boolean minimized) {
+	public void addView(String viewId, int relationship, float ratio, String refId, boolean minimized) {
 		if (minimized) {
 			E4Util.unsupported("addView: use of minimized for " + viewId + " ref " + refId); //$NON-NLS-1$ //$NON-NLS-2$
 		}
@@ -285,27 +280,23 @@ public class ModeledPageLayout implements IPageLayout {
 	}
 
 	protected void addViewActivator(MUIElement element) {
-		IPluginContribution contribution = (IPluginContribution) viewRegistry.find(element
-				.getElementId());
+		IPluginContribution contribution = (IPluginContribution) viewRegistry.find(element.getElementId());
 		IWorkbenchActivitySupport support = PlatformUI.getWorkbench().getActivitySupport();
-		IIdentifier identifier = support.getActivityManager().getIdentifier(
-				WorkbenchActivityHelper.createUnifiedId(contribution));
+		IIdentifier identifier = support.getActivityManager()
+				.getIdentifier(WorkbenchActivityHelper.createUnifiedId(contribution));
 		identifier.addIdentifierListener(new ViewActivator(element));
 	}
 
 	@Override
-	public IFolderLayout createFolder(String folderId, int relationship,
-			float ratio, String refId) {
-		MPartStack stack = insertStack(folderId, relationship, ratio, refId,
-				false);
+	public IFolderLayout createFolder(String folderId, int relationship, float ratio, String refId) {
+		MPartStack stack = insertStack(folderId, relationship, ratio, refId, false);
 		return new ModeledFolderLayout(this, application, stack);
 	}
 
 	@Override
-	public IPlaceholderFolderLayout createPlaceholderFolder(String folderId,
-			int relationship, float ratio, String refId) {
-		MPartStack Stack = insertStack(folderId, relationship, ratio, refId,
-				false);
+	public IPlaceholderFolderLayout createPlaceholderFolder(String folderId, int relationship, float ratio,
+			String refId) {
+		MPartStack Stack = insertStack(folderId, relationship, ratio, refId, false);
 		return new ModeledPlaceholderFolderLayout(this, application, Stack);
 	}
 
@@ -379,8 +370,7 @@ public class ModeledPageLayout implements IPageLayout {
 		// perspModel.setFixed(isFixed);
 	}
 
-	public static MStackElement createViewModel(MApplication application, String id,
-			boolean visible,
+	public static MStackElement createViewModel(MApplication application, String id, boolean visible,
 			WorkbenchPage page, EPartService partService, boolean createReferences) {
 		EModelService ms = application.getContext().get(EModelService.class);
 		MPartDescriptor partDesc = ms.getPartDescriptor(id);
@@ -397,10 +387,8 @@ public class ModeledPageLayout implements IPageLayout {
 			// there should only be view references for 3.x views that are
 			// visible to the end user, that is, the tab items are being
 			// drawn
-			if (visible
-					&& createReferences
-					&& CompatibilityPart.COMPATIBILITY_VIEW_URI.equals(partDesc
-							.getContributionURI())) {
+			if (visible && createReferences
+					&& CompatibilityPart.COMPATIBILITY_VIEW_URI.equals(partDesc.getContributionURI())) {
 				page.createViewReferenceForPart(part, id);
 			}
 			return ph;
@@ -408,22 +396,20 @@ public class ModeledPageLayout implements IPageLayout {
 		return null;
 	}
 
-	private MUIElement insertView(String viewId, int relationship, float ratio,
-			String refId, boolean visible, boolean withStack) {
+	private MUIElement insertView(String viewId, int relationship, float ratio, String refId, boolean visible,
+			boolean withStack) {
 
 		// Hide views that are filtered by capabilities
 		boolean isFiltered = isViewFiltered(viewId);
 
-		MStackElement viewModel = createViewModel(application, viewId, visible && !isFiltered,
-				page, partService,
+		MStackElement viewModel = createViewModel(application, viewId, visible && !isFiltered, page, partService,
 				createReferences);
 		MUIElement retVal = viewModel;
 
 		if (viewModel != null) {
 			if (withStack) {
 				String stackId = viewId + "MStack"; // Default id...basically unusable //$NON-NLS-1$
-				MPartStack stack = insertStack(stackId, relationship, ratio, refId, visible
-						& !isFiltered);
+				MPartStack stack = insertStack(stackId, relationship, ratio, refId, visible & !isFiltered);
 				stack.getChildren().add(viewModel);
 				retVal = stack;
 			} else {
@@ -458,8 +444,7 @@ public class ModeledPageLayout implements IPageLayout {
 		if (element instanceof MElementContainer<?>) {
 			MElementContainer<?> container = (MElementContainer<?>) element;
 			List<?> children = container.getChildren();
-			return children.isEmpty() ? container : getLastElement((MUIElement) children
-					.get(children.size() - 1));
+			return children.isEmpty() ? container : getLastElement((MUIElement) children.get(children.size() - 1));
 		}
 
 		MUIElement parent = element.getParent();
@@ -467,14 +452,14 @@ public class ModeledPageLayout implements IPageLayout {
 	}
 
 	/**
-	 * Returns the element that is the deepest and last element of the
-	 * containers underneath the current perspective. If this element's parent
-	 * is the perspective itself, the element will be returned. The perspective
-	 * will only be returned if the perspective itself has no children.
+	 * Returns the element that is the deepest and last element of the containers
+	 * underneath the current perspective. If this element's parent is the
+	 * perspective itself, the element will be returned. The perspective will only
+	 * be returned if the perspective itself has no children.
 	 *
-	 * @return the parent of the final element in the recursion chain of
-	 *         children, or the element itself if its parent is the perspective,
-	 *         or the perspective if the perspective itself has no children
+	 * @return the parent of the final element in the recursion chain of children,
+	 *         or the element itself if its parent is the perspective, or the
+	 *         perspective if the perspective itself has no children
 	 */
 	private MUIElement getLastElement() {
 		List<MPartSashContainerElement> children = perspModel.getChildren();
@@ -484,8 +469,7 @@ public class ModeledPageLayout implements IPageLayout {
 		return getLastElement(children.get(children.size() - 1));
 	}
 
-	private MPartStack insertStack(String stackId, int relationship,
-			float ratio, String refId, boolean visible) {
+	private MPartStack insertStack(String stackId, int relationship, float ratio, String refId, boolean visible) {
 		MUIElement refModel = findElement(perspModel, refId);
 		if (refModel == null) {
 			WorkbenchPlugin.log(NLS.bind(WorkbenchMessages.PageLayout_missingRefPart, refId));
@@ -518,8 +502,7 @@ public class ModeledPageLayout implements IPageLayout {
 		return stack;
 	}
 
-	public static void replace(MUIElement relTo,
-			MElementContainer<MUIElement> newParent) {
+	public static void replace(MUIElement relTo, MElementContainer<MUIElement> newParent) {
 		if (relTo == null || newParent == null)
 			return;
 
@@ -535,8 +518,7 @@ public class ModeledPageLayout implements IPageLayout {
 		kids.remove(relTo);
 	}
 
-	public static void insertParent(MElementContainer<MUIElement> newParent,
-			MUIElement relTo) {
+	public static void insertParent(MElementContainer<MUIElement> newParent, MUIElement relTo) {
 		if (newParent == null || relTo == null)
 			return;
 
@@ -550,8 +532,7 @@ public class ModeledPageLayout implements IPageLayout {
 	}
 
 	MUIElement findElement(MUIElement toSearch, String id) {
-		List<Object> found = modelService.findElements(toSearch, id, null, null,
-				EModelService.IN_ANY_PERSPECTIVE);
+		List<Object> found = modelService.findElements(toSearch, id, null, null, EModelService.IN_ANY_PERSPECTIVE);
 		if (found.size() > 0)
 			return (MUIElement) found.get(0);
 
@@ -594,8 +575,7 @@ public class ModeledPageLayout implements IPageLayout {
 	}
 
 	public void stackView(String id, String refId, boolean visible) {
-		MUIElement refModel = refId.equals(getEditorArea()) ? editorStack : findElement(perspModel,
-				refId);
+		MUIElement refModel = refId.equals(getEditorArea()) ? editorStack : findElement(perspModel, refId);
 		if (refModel == null && visible) {
 			addView(id, LEFT, DEFAULT_VIEW_RATIO, refId);
 			return;
@@ -613,8 +593,7 @@ public class ModeledPageLayout implements IPageLayout {
 		boolean isFiltered = isViewFiltered(id);
 		boolean toBeRendered = visible && !isFiltered;
 
-		MStackElement viewModel = createViewModel(application, id, toBeRendered, page, partService,
-				createReferences);
+		MStackElement viewModel = createViewModel(application, id, toBeRendered, page, partService, createReferences);
 		if (viewModel != null) {
 			MPartStack stack = (MPartStack) refModel;
 			boolean wasEmpty = stack.getChildren().isEmpty();
