@@ -23,13 +23,13 @@ import org.eclipse.ui.internal.registry.PreferenceTransferRegistryReader;
  */
 public class PreferenceTransferManager {
 
-    /**
-     * Return an array of <code>IPreferenceTransfer</code> objects
-     * @return an array of <code>IPreferenceTransfer</code> objects
-     */
-    public static PreferenceTransferElement[] getPreferenceTransfers() {
-        return new PreferenceTransferRegistryReader(
-                    IWorkbenchRegistryConstants.PL_PREFERENCE_TRANSFER)
-                    .getPreferenceTransfers();
-    }
+	/**
+	 * Return an array of <code>IPreferenceTransfer</code> objects
+	 * 
+	 * @return an array of <code>IPreferenceTransfer</code> objects
+	 */
+	public static PreferenceTransferElement[] getPreferenceTransfers() {
+		return new PreferenceTransferRegistryReader(IWorkbenchRegistryConstants.PL_PREFERENCE_TRANSFER)
+				.getPreferenceTransfers();
+	}
 }
