@@ -54,7 +54,8 @@ public interface IWorkbenchRegistryConstants {
 	String ATT_ALLOW_MULTIPLE = "allowMultiple"; //$NON-NLS-1$
 
 	/**
-	 * Attribute that specifies whether a view gets restored upon workbench restart. Value <code>restorable</code>.
+	 * Attribute that specifies whether a view gets restored upon workbench restart.
+	 * Value <code>restorable</code>.
 	 */
 	String ATT_RESTORABLE = "restorable"; //$NON-NLS-1$
 
@@ -65,8 +66,7 @@ public interface IWorkbenchRegistryConstants {
 	String ATT_CAN_FINISH_EARLY = "canFinishEarly"; //$NON-NLS-1$
 
 	/**
-	 * The name of the category attribute, which appears on a command
-	 * definition.
+	 * The name of the category attribute, which appears on a command definition.
 	 */
 	String ATT_CATEGORY = "category"; //$NON-NLS-1$
 
@@ -76,8 +76,8 @@ public interface IWorkbenchRegistryConstants {
 	String ATT_CATEGORY_ID = "categoryId"; //$NON-NLS-1$
 
 	/**
-	 * The name of the attribute storing checkEnabled for the visibleWhen
-	 * element. Value <code>checkEnabled</code>.
+	 * The name of the attribute storing checkEnabled for the visibleWhen element.
+	 * Value <code>checkEnabled</code>.
 	 */
 	String ATT_CHECK_ENABLED = "checkEnabled"; //$NON-NLS-1$
 
@@ -107,19 +107,18 @@ public interface IWorkbenchRegistryConstants {
 	String ATT_COMMAND_ID = "commandId"; //$NON-NLS-1$
 
 	/**
-	 * The name of the configuration attribute storing the scheme id for a
-	 * binding.
+	 * The name of the configuration attribute storing the scheme id for a binding.
 	 */
 	String ATT_CONFIGURATION = "configuration"; //$NON-NLS-1$
 
 	/**
-	 * Intro content detector class attribute (optional). Value <code>contentDetector</code>.
+	 * Intro content detector class attribute (optional). Value
+	 * <code>contentDetector</code>.
 	 */
 	String ATT_CONTENT_DETECTOR = "contentDetector"; //$NON-NLS-1$
 
 	/**
-	 * Editor content type id binding attribute. Value
-	 * <code>contentTypeId</code>.
+	 * Editor content type id binding attribute. Value <code>contentTypeId</code>.
 	 */
 	String ATT_CONTENT_TYPE_ID = "contentTypeId"; //$NON-NLS-1$
 
@@ -134,8 +133,8 @@ public interface IWorkbenchRegistryConstants {
 	String ATT_CONTRIBUTOR_CLASS = "contributorClass"; //$NON-NLS-1$
 
 	/**
-	 * The name of the attribute storing the AbstractParameterValueConverter for
-	 * a commandParameterType.
+	 * The name of the attribute storing the AbstractParameterValueConverter for a
+	 * commandParameterType.
 	 */
 	String ATT_CONVERTER = "converter"; //$NON-NLS-1$
 
@@ -166,8 +165,7 @@ public interface IWorkbenchRegistryConstants {
 	String ATT_DELETED = "deleted";//$NON-NLS-1$
 
 	/**
-	 * The name of the description attribute, which appears on named handle
-	 * objects.
+	 * The name of the description attribute, which appears on named handle objects.
 	 */
 	String ATT_DESCRIPTION = "description"; //$NON-NLS-1$
 
@@ -248,8 +246,8 @@ public interface IWorkbenchRegistryConstants {
 	String ATT_ID = "id"; //$NON-NLS-1$
 
 	/**
-	 * The name of the image style attribute, which is used on location elements
-	 * in the menus extension point.
+	 * The name of the image style attribute, which is used on location elements in
+	 * the menus extension point.
 	 */
 	String ATT_IMAGE_STYLE = "imageStyle"; //$NON-NLS-1$
 
@@ -266,14 +264,13 @@ public interface IWorkbenchRegistryConstants {
 	/**
 	 * The name of the attribute storing the identifier for the active key
 	 * configuration identifier. This provides legacy support for the
-	 * <code>activeKeyConfiguration</code> element in the commands extension
-	 * point.
+	 * <code>activeKeyConfiguration</code> element in the commands extension point.
 	 */
 	String ATT_KEY_CONFIGURATION_ID = "keyConfigurationId"; //$NON-NLS-1$
 
 	/**
-	 * The name of the attribute storing the trigger sequence for a binding.
-	 * This is called a 'keySequence' for legacy reasons.
+	 * The name of the attribute storing the trigger sequence for a binding. This is
+	 * called a 'keySequence' for legacy reasons.
 	 */
 	String ATT_KEY_SEQUENCE = "keySequence"; //$NON-NLS-1$
 
@@ -323,8 +320,8 @@ public interface IWorkbenchRegistryConstants {
 	String ATT_MNEMONIC = "mnemonic"; //$NON-NLS-1$
 
 	/**
-	 * The name of the minimized attribute, which appears
-	 * when adding a view in a perspectiveExtension.
+	 * The name of the minimized attribute, which appears when adding a view in a
+	 * perspectiveExtension.
 	 */
 	String ATT_MINIMIZED = "minimized"; //$NON-NLS-1$
 
@@ -359,8 +356,7 @@ public interface IWorkbenchRegistryConstants {
 	String ATT_OBJECTCLASS = "objectClass";//$NON-NLS-1$
 
 	/**
-	 * The name of the optional attribute, which appears on parameter
-	 * definitions.
+	 * The name of the optional attribute, which appears on parameter definitions.
 	 */
 	String ATT_OPTIONAL = "optional"; //$NON-NLS-1$
 
@@ -386,8 +382,8 @@ public interface IWorkbenchRegistryConstants {
 	String ATT_PARENT_ID = "parentId"; //$NON-NLS-1$
 
 	/**
-	 * The name of the deprecated parent scope attribute, which appears on
-	 * contexts definitions.
+	 * The name of the deprecated parent scope attribute, which appears on contexts
+	 * definitions.
 	 */
 	String ATT_PARENT_SCOPE = "parentScope"; //$NON-NLS-1$
 
@@ -423,8 +419,8 @@ public interface IWorkbenchRegistryConstants {
 	String ATT_PROJECT = "project";//$NON-NLS-1$ /**
 
 	/**
-	 * The name of the pulldown attribute, which indicates whether the class is
-	 * a pulldown delegate.
+	 * The name of the pulldown attribute, which indicates whether the class is a
+	 * pulldown delegate.
 	 */
 	String ATT_PULLDOWN = "pulldown"; //$NON-NLS-1$
 
@@ -454,14 +450,13 @@ public interface IWorkbenchRegistryConstants {
 	String ATT_RETARGET = "retarget";//$NON-NLS-1$
 
 	/**
-	 * The name of the returnTypeId attribute, which appears on command
-	 * elements.
+	 * The name of the returnTypeId attribute, which appears on command elements.
 	 */
 	String ATT_RETURN_TYPE_ID = "returnTypeId"; //$NON-NLS-1$
 
 	/**
-	 * The name of the attribute storing the identifier for the active scheme.
-	 * This is called a 'keyConfigurationId' for legacy reasons.
+	 * The name of the attribute storing the identifier for the active scheme. This
+	 * is called a 'keyConfigurationId' for legacy reasons.
 	 */
 	String ATT_SCHEME_ID = "schemeId"; //$NON-NLS-1$
 
@@ -471,8 +466,7 @@ public interface IWorkbenchRegistryConstants {
 	String ATT_SCOPE = "scope"; //$NON-NLS-1$
 
 	/**
-	 * The name of the separatorsVisible attribute, which appears on group
-	 * elements.
+	 * The name of the separatorsVisible attribute, which appears on group elements.
 	 */
 	String ATT_SEPARATORS_VISIBLE = "separatorsVisible"; //$NON-NLS-1$
 
@@ -492,7 +486,7 @@ public interface IWorkbenchRegistryConstants {
 	String ATT_SINGLETON = "singleton";//$NON-NLS-1$
 
 	/**
-	 * Splash id attribute.  Value <code>splashId</code>.
+	 * Splash id attribute. Value <code>splashId</code>.
 	 *
 	 * @since 3.3
 	 */
@@ -509,8 +503,8 @@ public interface IWorkbenchRegistryConstants {
 	String ATT_STATE = "state";//$NON-NLS-1$
 
 	/**
-	 * The name of the string attribute (key sequence) for a binding in the
-	 * commands extension point.
+	 * The name of the string attribute (key sequence) for a binding in the commands
+	 * extension point.
 	 */
 	String ATT_STRING = "string"; //$NON-NLS-1$
 
@@ -541,8 +535,7 @@ public interface IWorkbenchRegistryConstants {
 	String ATT_TYPE = "type"; //$NON-NLS-1$
 
 	/**
-	 * The name of the typeId attribute, which appears on commandParameter
-	 * elements.
+	 * The name of the typeId attribute, which appears on commandParameter elements.
 	 */
 	String ATT_TYPE_ID = "typeId"; //$NON-NLS-1$
 
@@ -564,14 +557,14 @@ public interface IWorkbenchRegistryConstants {
 
 	/**
 	 * The prefix that all auto-generated identifiers start with. This makes the
-	 * identifier recognizable as auto-generated, and further helps ensure that
-	 * it does not conflict with existing identifiers.
+	 * identifier recognizable as auto-generated, and further helps ensure that it
+	 * does not conflict with existing identifiers.
 	 */
 	String AUTOGENERATED_PREFIX = "AUTOGEN:::"; //$NON-NLS-1$
 
 	/**
-	 * The legacy extension point (2.1.x and earlier) for specifying a key
-	 * binding scheme.
+	 * The legacy extension point (2.1.x and earlier) for specifying a key binding
+	 * scheme.
 	 *
 	 * @since 3.1.1
 	 */
@@ -600,8 +593,8 @@ public interface IWorkbenchRegistryConstants {
 	String PL_ACTIVITYSUPPORT = "activitySupport"; //$NON-NLS-1$
 
 	/**
-	 * The extension point (3.1 and later) for specifying bindings, such as
-	 * keyboard shortcuts.
+	 * The extension point (3.1 and later) for specifying bindings, such as keyboard
+	 * shortcuts.
 	 *
 	 * @since 3.1.1
 	 */
@@ -620,8 +613,8 @@ public interface IWorkbenchRegistryConstants {
 
 	/**
 	 * The extension point (2.1.x and later) for specifying a command. A lot of
-	 * other things have appeared first in this extension point and then been
-	 * moved to their own extension point.
+	 * other things have appeared first in this extension point and then been moved
+	 * to their own extension point.
 	 *
 	 * @since 3.1.1
 	 */
@@ -718,92 +711,78 @@ public interface IWorkbenchRegistryConstants {
 
 	String PL_WORKINGSETS = "workingSets"; //$NON-NLS-1$
 
+	String PL_QUICK_ACCESS = "quickAccess"; //$NON-NLS-1$
+
 	/**
 	 * The name of the deprecated accelerator configurations extension point.
 	 */
-	String EXTENSION_ACCELERATOR_CONFIGURATIONS = PlatformUI.PLUGIN_ID
-			+ '.' + PL_ACCELERATOR_CONFIGURATIONS;
+	String EXTENSION_ACCELERATOR_CONFIGURATIONS = PlatformUI.PLUGIN_ID + '.' + PL_ACCELERATOR_CONFIGURATIONS;
 
 	/**
 	 * The name of the accelerator scopes extension point.
 	 */
-	String EXTENSION_ACCELERATOR_SCOPES = PlatformUI.PLUGIN_ID
-			+ '.' + PL_ACCELERATOR_SCOPES;
+	String EXTENSION_ACCELERATOR_SCOPES = PlatformUI.PLUGIN_ID + '.' + PL_ACCELERATOR_SCOPES;
 
 	/**
 	 * The name of the action definitions extension point.
 	 */
-	String EXTENSION_ACTION_DEFINITIONS = PlatformUI.PLUGIN_ID
-			+ '.' + PL_ACTION_DEFINITIONS;
+	String EXTENSION_ACTION_DEFINITIONS = PlatformUI.PLUGIN_ID + '.' + PL_ACTION_DEFINITIONS;
 
 	/**
 	 * The name of the <code>org.eclipse.ui.actionSets</code> extension point.
 	 */
-	String EXTENSION_ACTION_SETS = PlatformUI.PLUGIN_ID
-			+ '.' + IWorkbenchRegistryConstants.PL_ACTION_SETS;
+	String EXTENSION_ACTION_SETS = PlatformUI.PLUGIN_ID + '.' + IWorkbenchRegistryConstants.PL_ACTION_SETS;
 
 	/**
 	 * The name of the bindings extension point.
 	 */
-	String EXTENSION_BINDINGS = PlatformUI.PLUGIN_ID + '.'
-			+ PL_BINDINGS;
+	String EXTENSION_BINDINGS = PlatformUI.PLUGIN_ID + '.' + PL_BINDINGS;
 
 	/**
 	 * The name of the commands extension point.
 	 */
-	String EXTENSION_COMMAND_IMAGES = PlatformUI.PLUGIN_ID
-			+ '.' + PL_COMMAND_IMAGES;
+	String EXTENSION_COMMAND_IMAGES = PlatformUI.PLUGIN_ID + '.' + PL_COMMAND_IMAGES;
 
 	/**
 	 * The name of the commands extension point, and the name of the key for the
 	 * commands preferences.
 	 */
-	String EXTENSION_COMMANDS = PlatformUI.PLUGIN_ID + '.'
-			+ PL_COMMANDS;
+	String EXTENSION_COMMANDS = PlatformUI.PLUGIN_ID + '.' + PL_COMMANDS;
 
 	/**
 	 * The name of the contexts extension point.
 	 */
-	String EXTENSION_CONTEXTS = PlatformUI.PLUGIN_ID + '.'
-			+ PL_CONTEXTS;
+	String EXTENSION_CONTEXTS = PlatformUI.PLUGIN_ID + '.' + PL_CONTEXTS;
 
 	/**
-	 * The name of the <code>org.eclipse.ui.editorActions</code> extension
-	 * point.
+	 * The name of the <code>org.eclipse.ui.editorActions</code> extension point.
 	 */
-	String EXTENSION_EDITOR_ACTIONS = PlatformUI.PLUGIN_ID
-			+ '.' + PL_EDITOR_ACTIONS;
+	String EXTENSION_EDITOR_ACTIONS = PlatformUI.PLUGIN_ID + '.' + PL_EDITOR_ACTIONS;
 
 	/**
 	 * The name of the commands extension point.
 	 */
-	String EXTENSION_HANDLERS = PlatformUI.PLUGIN_ID + '.'
-			+ PL_HANDLERS;
+	String EXTENSION_HANDLERS = PlatformUI.PLUGIN_ID + '.' + PL_HANDLERS;
 
 	/**
 	 * The name of the <code>org.eclipse.ui.menus</code> extension point.
 	 */
-	String EXTENSION_MENUS = PlatformUI.PLUGIN_ID + '.'
-			+ PL_MENUS;
+	String EXTENSION_MENUS = PlatformUI.PLUGIN_ID + '.' + PL_MENUS;
 
 	/**
 	 * The name of the <code>org.eclipse.ui.menus2</code> extension point.
 	 */
-	String COMMON_MENU_ADDITIONS = PlatformUI.PLUGIN_ID + '.'
-			+ PL_MENUS + '2';
+	String COMMON_MENU_ADDITIONS = PlatformUI.PLUGIN_ID + '.' + PL_MENUS + '2';
 
 	/**
 	 * The name of the <code>org.eclipse.ui.popupMenus</code> extension point.
 	 */
-	String EXTENSION_POPUP_MENUS = PlatformUI.PLUGIN_ID
-			+ '.' + PL_POPUP_MENU;
+	String EXTENSION_POPUP_MENUS = PlatformUI.PLUGIN_ID + '.' + PL_POPUP_MENU;
 
 	/**
-	 * The name of the <code>org.eclipse.ui.viewActions</code> extension
-	 * point.
+	 * The name of the <code>org.eclipse.ui.viewActions</code> extension point.
 	 */
-	String EXTENSION_VIEW_ACTIONS = PlatformUI.PLUGIN_ID
-			+ '.' + PL_VIEW_ACTIONS;
+	String EXTENSION_VIEW_ACTIONS = PlatformUI.PLUGIN_ID + '.' + PL_VIEW_ACTIONS;
 
 	/**
 	 * The constant for the position attribute corresponding to
@@ -845,9 +824,9 @@ public interface IWorkbenchRegistryConstants {
 	String STYLE_TOGGLE = "toggle"; //$NON-NLS-1$
 
 	/**
-	 * The name of the deprecated accelerator configuration element. This
-	 * element was used in 2.1.x and earlier to define groups of what are now
-	 * called schemes.
+	 * The name of the deprecated accelerator configuration element. This element
+	 * was used in 2.1.x and earlier to define groups of what are now called
+	 * schemes.
 	 */
 	String TAG_ACCELERATOR_CONFIGURATION = "acceleratorConfiguration"; //$NON-NLS-1$
 
@@ -886,8 +865,7 @@ public interface IWorkbenchRegistryConstants {
 	String TAG_SEQUENCE_MODIFIER = "sequenceModifier"; //$NON-NLS-1$
 
 	/**
-	 * The name of the active when element, which appears on a handler
-	 * definition.
+	 * The name of the active when element, which appears on a handler definition.
 	 */
 	String TAG_ACTIVE_WHEN = "activeWhen"; //$NON-NLS-1$
 
@@ -923,8 +901,7 @@ public interface IWorkbenchRegistryConstants {
 	String TAG_CATEGORYDEFINITION = "themeElementCategory"; //$NON-NLS-1$
 
 	/**
-	 * Category presentation tag. Value <code>categoryPresentationBinding</code>
-	 * .
+	 * Category presentation tag. Value <code>categoryPresentationBinding</code> .
 	 *
 	 * @deprecated used by the removal presentation API
 	 */
@@ -1016,8 +993,7 @@ public interface IWorkbenchRegistryConstants {
 	String TAG_EDITOR_CONTRIBUTION = "editorContribution"; //$NON-NLS-1$
 
 	/**
-	 * The name of the enabled when element, which appears on a handler
-	 * definition.
+	 * The name of the enabled when element, which appears on a handler definition.
 	 */
 	String TAG_ENABLED_WHEN = "enabledWhen"; //$NON-NLS-1$
 
@@ -1103,8 +1079,8 @@ public interface IWorkbenchRegistryConstants {
 
 	/**
 	 * The name of the deprecated key configuration element in the commands
-	 * extension point. This element has been replaced with the scheme element
-	 * in the bindings extension point.
+	 * extension point. This element has been replaced with the scheme element in
+	 * the bindings extension point.
 	 */
 	String TAG_KEY_CONFIGURATION = "keyConfiguration"; //$NON-NLS-1$
 
@@ -1114,8 +1090,7 @@ public interface IWorkbenchRegistryConstants {
 	String TAG_LOCATION = "location"; //$NON-NLS-1$
 
 	/**
-	 * The name of the element defining the insertion point for menu
-	 * additions.
+	 * The name of the element defining the insertion point for menu additions.
 	 *
 	 * @since 3.3
 	 */
@@ -1206,7 +1181,6 @@ public interface IWorkbenchRegistryConstants {
 	 */
 	String TAG_SEPARATOR = "separator"; //$NON-NLS-1$
 
-
 	/**
 	 * Tag for the settings transfer entry.
 	 */
@@ -1225,14 +1199,15 @@ public interface IWorkbenchRegistryConstants {
 	/**
 	 * The name of the element describing splash handlers. Value
 	 * <code>splashHandler</code>.
+	 * 
 	 * @since 3.3
 	 */
 	String TAG_SPLASH_HANDLER = "splashHandler"; //$NON-NLS-1$
 
-
 	/**
 	 * The name of the element describing splash handler product bindings. Value
 	 * <code>splashHandlerProductBinding</code>.
+	 * 
 	 * @since 3.3
 	 */
 	String TAG_SPLASH_HANDLER_PRODUCT_BINDING = "splashHandlerProductBinding"; //$NON-NLS-1$
@@ -1273,8 +1248,8 @@ public interface IWorkbenchRegistryConstants {
 	String TAG_VIEW = "view";//$NON-NLS-1$
 
 	/**
-	 * E4 view tag, used in the <code>org.eclipse.ui.view</code> extension point
-	 * to point to a POJO class. Value <code>e4view</code>.
+	 * E4 view tag, used in the <code>org.eclipse.ui.view</code> extension point to
+	 * point to a POJO class. Value <code>e4view</code>.
 	 */
 	String TAG_E4VIEW = "e4view";//$NON-NLS-1$
 
