@@ -1,3 +1,16 @@
+/*******************************************************************************
+ * Copyright (c) 2014 Lars Vogel and others.
+ *
+ * This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License 2.0
+ * which accompanies this distribution, and is available at
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
+ *
+ * Contributors:
+ *     Lars Vogel - initial API and implementation
+ *******************************************************************************/
 package org.eclipse.ui.examples.adapterservice.snippets.adapter;
 
 import java.util.HashMap;
@@ -22,12 +35,7 @@ public class IDAssigner implements IAdapterFactory {
 				currentId++;
 				assignedIds.put(adaptableObject, id);
 			}
-			return new ThingWithId() {
-				@Override
-				public String getUniqueId() {
-					return assignedIds.get(adaptableObject);
-				}
-			};
+			return (ThingWithId) () -> assignedIds.get(adaptableObject);
 		}
 		return null;
 	}
