@@ -16,7 +16,7 @@ package org.eclipse.core.tests.databinding.beans;
 
 import static org.junit.Assert.assertEquals;
 
-import org.eclipse.core.databinding.beans.BeanProperties;
+import org.eclipse.core.databinding.beans.typed.BeanProperties;
 import org.eclipse.core.databinding.observable.value.IObservableValue;
 import org.eclipse.core.databinding.observable.value.WritableValue;
 import org.eclipse.core.databinding.property.value.IValueProperty;
@@ -31,10 +31,10 @@ public class AnonymousBeanValuePropertyTest extends
 		AbstractDefaultRealmTestCase {
 	@Test
 	public void testObserveDetailHavingNullValueType_UseExplicitValueType() {
-		IObservableValue master = WritableValue.withValueType(null);
-		IValueProperty prop = BeanProperties.value("value", String.class);
+		IObservableValue<Object> master = WritableValue.withValueType(null);
+		IValueProperty<Object, ?> prop = BeanProperties.value("value", String.class);
 
-		IObservableValue detail = prop.observeDetail(master);
+		IObservableValue<?> detail = prop.observeDetail(master);
 
 		assertEquals(String.class, detail.getValueType());
 	}
