@@ -29,42 +29,44 @@ import org.eclipse.core.databinding.validation.IValidator;
  * for validating.
  *
  */
-public class CustomBeanUpdateValueStrategy extends UpdateValueStrategy {
+public class CustomBeanUpdateValueStrategy<S, D> extends UpdateValueStrategy<S, D> {
 
 	@Override
-	public IConverter createConverter(Object fromType, Object toType) {
+	public IConverter<?, ?> createConverter(Object fromType, Object toType) {
 		if (fromType instanceof CustomBeanModelType) {
-			CustomBeanModelType customBeanModelType = (CustomBeanModelType) fromType;
+			@SuppressWarnings("unchecked")
+			CustomBeanModelType<S> customBeanModelType = (CustomBeanModelType<S>) fromType;
 			fromType = customBeanModelType.getType();
 		}
 		if (toType instanceof CustomBeanModelType) {
-			CustomBeanModelType customBeanModelType = (CustomBeanModelType) toType;
+			@SuppressWarnings("unchecked")
+			CustomBeanModelType<D> customBeanModelType = (CustomBeanModelType<D>) toType;
 			toType = customBeanModelType.getType();
 		}
 		return super.createConverter(fromType, toType);
 	}
 
+	@SuppressWarnings("unchecked")
 	@Override
-	protected void fillDefaults(IObservableValue source,
-			IObservableValue destination) {
+	protected void fillDefaults(IObservableValue<? extends S> source, IObservableValue<? super D> destination) {
 		if (destination.getValueType() instanceof CustomBeanModelType) {
 			if (beforeSetValidator==null) {
-				CustomBeanModelType property = (CustomBeanModelType) destination.getValueType();
+				CustomBeanModelType<?> property = (CustomBeanModelType<?>) destination.getValueType();
 				String propertyName = property.getPropertyName();
 				String getValidatorMethodName = "get" + upperCaseFirstLetter(propertyName) + "Validator"; //$NON-NLS-1$ //$NON-NLS-2$
 
-				Class objectClass = property.getObject().getClass();
+				Class<?> objectClass = property.getObject().getClass();
 
 				Method getValidator;
 				try {
 					getValidator = objectClass.getMethod(getValidatorMethodName, Class.class);
-					beforeSetValidator = (IValidator) getValidator.invoke(property.getObject());
+					beforeSetValidator = (IValidator<D>) getValidator.invoke(property.getObject());
 				} catch (Exception e) {
 					// ignore
 				}
 
 			}
- 		}
+		}
 		super.fillDefaults(source, destination);
 	}
 
@@ -76,10 +78,10 @@ public class CustomBeanUpdateValueStrategy extends UpdateValueStrategy {
 	@Override
 	public Boolean isAssignableFromTo(Object fromType, Object toType) {
 		if (fromType instanceof CustomBeanModelType) {
-			fromType = ((CustomBeanModelType) fromType).getType();
+			fromType = ((CustomBeanModelType<?>) fromType).getType();
 		}
 		if (toType instanceof CustomBeanModelType) {
-			toType = ((CustomBeanModelType) toType).getType();
+			toType = ((CustomBeanModelType<?>) toType).getType();
 		}
 		return super.isAssignableFromTo(fromType, toType);
 	}
