@@ -443,7 +443,7 @@ public class XMLMementoTest extends TestCase {
 				@Override
 				public void checkAfterDeserialization(
 						XMLMemento deserializedMemento) {
-					if (data.equals("")) {
+					if (data.isEmpty()) {
 						// this comes back as null...
 						assertEquals(null, deserializedMemento.getTextData());
 					} else {
@@ -548,15 +548,15 @@ public class XMLMementoTest extends TestCase {
 
 	}
 
-	   public void testMementoWithTextContent113659() throws Exception {
-	        IMemento memento = XMLMemento.createWriteRoot("root");
-	        IMemento mementoWithChild = XMLMemento.createWriteRoot("root");
-	        IMemento child = mementoWithChild.createChild("child");
-	        child.putTextData("text");
-	        memento.putMemento(mementoWithChild);
-	        IMemento copiedChild = memento.getChild("child");
-	        assertEquals("text", copiedChild.getTextData());
-	    }
+		public void testMementoWithTextContent113659() throws Exception {
+			IMemento memento = XMLMemento.createWriteRoot("root");
+			IMemento mementoWithChild = XMLMemento.createWriteRoot("root");
+			IMemento child = mementoWithChild.createChild("child");
+			child.putTextData("text");
+			memento.putMemento(mementoWithChild);
+			IMemento copiedChild = memento.getChild("child");
+			assertEquals("text", copiedChild.getTextData());
+		}
 
 
 
