@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2007, 2018 IBM Corporation and others.
+ * Copyright (c) 2007, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -61,12 +61,17 @@ import org.eclipse.ui.tests.commands.ActiveContextExpression;
 import org.eclipse.ui.tests.harness.util.UITestCase;
 import org.junit.Assume;
 import org.junit.FixMethodOrder;
+import org.junit.Ignore;
+import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.junit.runners.BlockJUnit4ClassRunner;
 import org.junit.runners.MethodSorters;
 
 /**
  * @since 3.3
  *
  */
+@RunWith(BlockJUnit4ClassRunner.class)
 @FixMethodOrder(MethodSorters.NAME_ASCENDING)
 public class EvaluationServiceTest extends UITestCase {
 	/**
@@ -78,8 +83,8 @@ public class EvaluationServiceTest extends UITestCase {
 	/**
 	 * @param testName
 	 */
-	public EvaluationServiceTest(String testName) {
-		super(testName);
+	public EvaluationServiceTest() {
+		super(EvaluationServiceTest.class.getName());
 	}
 
 	private static class MyEval implements IPropertyChangeListener {
@@ -96,6 +101,7 @@ public class EvaluationServiceTest extends UITestCase {
 		}
 	}
 
+	@Test
 	public void testBug334524() throws Exception {
 		IPerspectiveRegistry registry = PlatformUI.getWorkbench().getPerspectiveRegistry();
 		IPerspectiveDescriptor resourecePerspective = registry.findPerspectiveWithId("org.eclipse.ui.resourcePerspective");
@@ -130,6 +136,7 @@ public class EvaluationServiceTest extends UITestCase {
 
 	}
 
+	@Test
 	public void testBasicService() throws Exception {
 		IWorkbenchWindow window = openTestWindow();
 		waitForJobs(500, 5000);
@@ -199,6 +206,7 @@ public class EvaluationServiceTest extends UITestCase {
 		}
 	}
 
+	@Test
 	public void testTwoEvaluations() throws Exception {
 		IWorkbenchWindow window = openTestWindow();
 		boolean activeShell = forceActive(window.getShell());
@@ -281,8 +289,9 @@ public class EvaluationServiceTest extends UITestCase {
 		}
 	}
 
-	// TODO fix testRestriction
-	public void TODOtestRestriction() {
+	@Test
+	@Ignore // TODO fix testRestriction
+	public void testRestriction() {
 		IWorkbenchWindow window = openTestWindow();
 		IEvaluationService evaluationService = window
 				.getService(IEvaluationService.class);
@@ -361,8 +370,9 @@ public class EvaluationServiceTest extends UITestCase {
 		assertTrue(propertyShouldChange[0]);
 	}
 
-	// TODO fix testScopedService
-	public void TODOtestScopedService() throws Exception {
+	@Test
+	@Ignore // TODO fix testScopedService
+	public void testScopedService() throws Exception {
 		IWorkbenchWindow window = openTestWindow();
 		IEvaluationService service = window
 				.getService(IEvaluationService.class);
@@ -422,6 +432,7 @@ public class EvaluationServiceTest extends UITestCase {
 		}
 	}
 
+	@Test
 	public void testSourceProvider() throws Exception {
 		IWorkbenchWindow window = openTestWindow();
 		IEvaluationService service = window
@@ -454,6 +465,7 @@ public class EvaluationServiceTest extends UITestCase {
 		assertEquals(3, listener.count);
 	}
 
+	@Test
 	@SuppressWarnings("unchecked")
 	public void testSourceProviderPriority() throws Exception {
 		IHandlerService hs = getWorkbench().getService(IHandlerService.class);
@@ -501,6 +513,7 @@ public class EvaluationServiceTest extends UITestCase {
 		assertEquals(ISources.ACTIVE_CONTEXT<<1, activation.getSourcePriority());
 	}
 
+	@Test
 	public void testPropertyChange() throws Exception {
 		IWorkbenchWindow window = openTestWindow();
 		IEvaluationService service = window
@@ -538,6 +551,7 @@ public class EvaluationServiceTest extends UITestCase {
 		assertEquals(2, listener.count);
 	}
 
+	@Test
 	public void testPlatformProperty() throws Exception {
 		IEvaluationService evaluationService = PlatformUI
 				.getWorkbench().getService(IEvaluationService.class);
@@ -550,7 +564,9 @@ public class EvaluationServiceTest extends UITestCase {
 		assertEquals(EvaluationResult.TRUE, result);
 	}
 
-	public void XtestSystemProperty() throws Exception {
+	@Test
+	@Ignore
+	public void testSystemProperty() throws Exception {
 		// this is not added, as the ability to test system properties with
 		// no '.' seems unhelpful
 		System.setProperty("isHere", "true");
@@ -598,6 +614,7 @@ public class EvaluationServiceTest extends UITestCase {
 		}
 	}
 
+	@Test
 	public void testWorkbenchProvider() throws Exception {
 
 		IWorkbenchWindow window = openTestWindow();
