@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2003, 2015 IBM Corporation and others.
+ * Copyright (c) 2003, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -11,35 +11,23 @@
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *     Lars Vogel <Lars.Vogel@vogella.com> - Bug 474132
+ *     Paul Pazderski - Bug 546537: migrate to JUnit4 suite because EvaluationServiceTest use JUnit4 features
  *******************************************************************************/
 package org.eclipse.ui.tests.services;
 
 import org.junit.runner.RunWith;
-
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import org.junit.runners.Suite;
 
 /**
  * Tests general to services.
  * @since 3.3
  */
-@RunWith(org.junit.runners.AllTests.class)
-public final class ServicesTestSuite extends TestSuite {
-
-	/**
-	 * Returns the suite. This is required to use the JUnit Launcher.
-	 */
-	public static final Test suite() {
-		return new ServicesTestSuite();
-	}
-
-	/**
-	 * Construct the test suite.
-	 */
-	public ServicesTestSuite() {
-		addTest(new TestSuite(EvaluationServiceTest.class));
-		addTest(ContributedServiceTest.suite());
-		addTest(new TestSuite(WorkbenchSiteProgressServiceTest.class));
-		// TODO addTest(new TestSuite(EditorSourceTest.class));
-	}
+@RunWith(Suite.class)
+@Suite.SuiteClasses({
+	EvaluationServiceTest.class,
+	ContributedServiceTest.class,
+	WorkbenchSiteProgressServiceTest.class,
+// TODO EditorSourceTest.class
+	})
+public final class ServicesTestSuite {
 }
